@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -338,7 +338,7 @@ create_addressbook_settings()
     scale_button = gtk_hbox_new (FALSE, 0);
     scale_label = gtk_label_new (_ ("Download limit :"));
     gtk_box_pack_start (GTK_BOX (scale_button),scale_label,FALSE,FALSE,0);
-    value = gtk_spin_button_new_with_range (1, 500, 1);
+    value = gtk_spin_button_new_with_range (1, G_MAXINT, 1);
     gtk_label_set_mnemonic_widget (GTK_LABEL (scale_label), value);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (value) , addressbook_config->max_results);
     g_signal_connect (G_OBJECT (value) , "value-changed" , G_CALLBACK (max_results_cb), NULL);
