@@ -76,7 +76,6 @@ typedef struct {
     gboolean isdefault;
 } book_data_t;
 
-GSList *books_data;
 
 /**
  * Free a contact entry
@@ -164,6 +163,12 @@ set_current_addressbook_test (EBookQueryTest test);
 EBookQueryTest
 get_current_addressbook_test (void);
 
+GSList *
+get_books_data();
+
+void
+determine_default_addressbook();
+
 
 G_END_DECLS
 
