@@ -43,11 +43,18 @@
 #include "../imwindow.h"
 #include "searchbar.h"
 
+// Messages used in menu item
+#define SFL_CREATE_CONFERENCE "Create conference"
+#define SFL_TRANSFER_CALL "Transfer call to"
+
 GtkWidget *sw;
 GtkCellRenderer *rend;
 GtkTreeViewColumn *col;
 GtkTreeSelection *sel;
 
+GtkWidget *popupmenu = NULL;
+GtkWidget *menu_items = NULL;
+
 gint dragged_type;
 gint selected_type;
 
@@ -70,7 +77,7 @@ conference_obj_t *selected_conf;
 static void drag_begin_cb (GtkWidget *widget, GdkDragContext *dc, gpointer data);
 static void drag_end_cb (GtkWidget * mblist, GdkDragContext * context, gpointer data);
 void drag_data_received_cb (GtkWidget *widget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint t, gpointer data);
-
+static void menuitem_response (gchar *);
 
 enum {
     COLUMN_ACCOUNT_STATE = 0,
@@ -533,6 +540,9 @@ focus_on_calltree_in()
 void
 calltree_create (calltab_t* tab, gboolean searchbar_type)
 {
+    gchar *conference = SFL_CREATE_CONFERENCE;
+    gchar *transfer = SFL_TRANSFER_CALL;
+
 
     tab->tree = gtk_vbox_new (FALSE, 10);
 
@@ -594,6 +604,22 @@ calltree_create (calltab_t* tab, gboolean searchbar_type)
         // destination widget drag n drop signals
         g_signal_connect (G_OBJECT (tab->view), "drag_data_received", G_CALLBACK (drag_data_received_cb), NULL);
 
+        popupmenu = gtk_menu_new ();
+
+        menu_items = gtk_menu_item_new_with_label (transfer);
+        g_signal_connect_swapped (menu_items, "activate",
+                                  G_CALLBACK (menuitem_response), (gpointer) g_strdup (transfer));
+        gtk_menu_shell_append (GTK_MENU_SHELL (popupmenu), menu_items);
+        gtk_widget_show (menu_items);
+
+        menu_items = gtk_menu_item_new_with_label (conference);
+        g_signal_connect_swapped (menu_items, "activate",
+                                  G_CALLBACK (menuitem_response), (gpointer) g_strdup (conference));
+        gtk_menu_shell_append (GTK_MENU_SHELL (popupmenu), menu_items);
+        gtk_widget_show (menu_items);
+
+
+
     }
 
 
@@ -1561,8 +1587,14 @@ static void drag_end_cb (GtkWidget * widget UNUSED, GdkDragContext * context UNU
                     // draged a call on itself
                 } else {
                     // dragged a single call on a single call
-                    if (selected_call != NULL && dragged_call != NULL)
-                        sflphone_join_participant (selected_call->_callID, dragged_call->_callID);
+                    if (selected_call != NULL && dragged_call != NULL) {
+                        calltree_remove_call (current_calls, selected_call, NULL);
+                        calltree_add_call (current_calls, selected_call, NULL);
+                        gtk_menu_popup (GTK_MENU (popupmenu), NULL, NULL, NULL, NULL,
+                                               0, 0);
+
+                        // sflphone_join_participant (selected_call->_callID, dragged_call->_callID);
+                    }
                 }
             } else if (selected_type == A_CALL && dragged_type == A_CONFERENCE) {
 
@@ -1635,8 +1667,6 @@ static void drag_end_cb (GtkWidget * widget UNUSED, GdkDragContext * context UNU
         }
     } else {
 
-        // selected_path_depth == 2
-
         if (dragged_path_depth == 1) {
 
             if (selected_type == A_CALL && dragged_type == A_CALL) {
@@ -1644,8 +1674,12 @@ static void drag_end_cb (GtkWidget * widget UNUSED, GdkDragContext * context UNU
                 // dragged a conference call on a call
                 sflphone_detach_participant (selected_call_id);
 
-                if (selected_call != NULL && dragged_call != NULL)
-                    sflphone_join_participant (selected_call->_callID, dragged_call->_callID);
+                if (selected_call != NULL && dragged_call != NULL) {
+                    // sflphone_join_participant (selected_call->_callID, dragged_call->_callID);
+                    gtk_menu_popup (GTK_MENU (popupmenu), NULL, NULL, NULL, NULL,
+                                                                   0, 0);
+
+                }
 
             } else if (selected_type == A_CALL && dragged_type == A_CONFERENCE) {
 
@@ -1682,6 +1716,9 @@ static void drag_end_cb (GtkWidget * widget UNUSED, GdkDragContext * context UNU
                 DEBUG ("Dragged a call in the same conference");
                 calltree_remove_call (current_calls, selected_call, NULL);
                 calltree_add_call (current_calls, selected_call, &parent_conference);
+                gtk_widget_hide(menu_items);
+                gtk_menu_popup (GTK_MENU (popupmenu), NULL, NULL, NULL, NULL,
+                                                               0, 0);
             } else {
 
 
@@ -1812,3 +1849,27 @@ void drag_data_received_cb (GtkWidget *widget, GdkDragContext *context UNUSED, g
         }
     }
 }
+
+/* Print a string when a menu item is selected */
+
+static void menuitem_response( gchar *string )
+{
+    if(g_strcmp0(string, SFL_CREATE_CONFERENCE) == 0) {
+        sflphone_join_participant (selected_call->_callID, dragged_call->_callID);
+    }
+    else if(g_strcmp0(string, SFL_TRANSFER_CALL) == 0) {
+        g_print("Calltree: Transfering call %s, to %s", selected_call->_peer_number, dragged_call->_peer_number);
+        dbus_attended_transfer(selected_call, dragged_call);
+        calltree_remove_call(current_calls, selected_call, NULL);
+    }
+    else {
+        g_print("CallTree: Error unknown option selected in menu %s", string);
+    }
+
+    // Make sure the create conference opetion will appear next time the menu pops
+    // The create conference option will hide if tow call from the same conference are draged on each other
+    gtk_widget_show(menu_items);
+
+    printf ("%s\n", string);
+}
+
