@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *
  *  Author: Antoine Reversat <antoine.reversat@savoirfairelinux.com>
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
@@ -53,7 +53,6 @@ GdkPixbuf *outgoing_pixbuf = NULL;
 GdkPixbuf *missed_pixbuf = NULL;
 
 
-
 void searchbar_addressbook_activated (GtkEntry *entry, gchar *arg1 UNUSED, gpointer data UNUSED)
 {
     DEBUG ("Searchbar: Entry activated");
@@ -77,6 +76,8 @@ static void cbox_changed_cb (GtkWidget *widget, gpointer user_data UNUSED)
 {
     gchar *name;
 
+    DEBUG ("Searchbar: CBOX changed callback");
+
     name = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
 
     set_current_addressbook (name);
@@ -84,6 +85,12 @@ static void cbox_changed_cb (GtkWidget *widget, gpointer user_data UNUSED)
     addressbook_search (GTK_ENTRY (addressbookentry));
 }
 
+void set_forcus_on_addressbook_searchbar ()
+{
+
+    gtk_widget_grab_focus (addressbookentry);
+}
+
 void update_searchbar_addressbook_list()
 {
     gint count;
@@ -93,6 +100,8 @@ void update_searchbar_addressbook_list()
     book_data_t *book_data;
     GSList *books_data = addressbook_get_books_data();
 
+    DEBUG ("Searchbar: Update addressbook list");
+
     // we must disconnect signal from teh cbox while updating its content
     gtk_signal_disconnect (cbox, cboxSignalId);
 
@@ -259,7 +268,7 @@ GtkWidget *addressbook_menu_new (void)
 void
 focus_on_searchbar_out()
 {
-    DEBUG ("set_focus_on_searchbar_out");
+    DEBUG ("Searchbar: Unset focus from search bar");
     // gtk_widget_grab_focus(GTK_WIDGET(sw));
     focus_is_on_searchbar = FALSE;
 }
@@ -267,7 +276,7 @@ focus_on_searchbar_out()
 void
 focus_on_searchbar_in()
 {
-    DEBUG ("set_focus_on_searchbar_in");
+    DEBUG ("Searchbar: Set focus on search bar");
     // gtk_widget_grab_focus(GTK_WIDGET(sw));
     focus_is_on_searchbar = TRUE;
 }
@@ -365,6 +374,9 @@ GtkWidget* contacts_searchbar_new ()
     int count, cbox_height, cbox_width;
     GtkTreeIter iter, activeIter;
     GtkCellRenderer *cell;
+    // gchar *current_addressbook = NULL;
+
+    DEBUG ("Addressbook: Create addressbook search bar");
 
     ret = gtk_hbox_new (FALSE, 0);
 
@@ -380,13 +392,14 @@ GtkWidget* contacts_searchbar_new ()
     count = 0;
     gboolean activeIsSet = FALSE;
 
-    for (book_list_iterator = books_data; book_list_iterator != NULL; book_list_iterator
-            = book_list_iterator->next) {
+    for (book_list_iterator = books_data; book_list_iterator != NULL;
+            book_list_iterator = book_list_iterator->next) {
         book_data = (book_data_t *) book_list_iterator->data;
 
         if (book_data->active) {
 
             gtk_list_store_append (liststore, &iter);
+
             gtk_list_store_set (liststore, &iter, 0, book_data->name, -1);
 
             if (book_data->isdefault) {
@@ -398,6 +411,8 @@ GtkWidget* contacts_searchbar_new ()
         }
     }
 
+    // current_addressbook = get_current_addressbook();
+
     cbox = gtk_combo_box_new_with_model ( (GtkTreeModel *) liststore);
 
     if (activeIsSet)
@@ -413,11 +428,14 @@ GtkWidget* contacts_searchbar_new ()
     gtk_widget_set_size_request (GTK_WIDGET (cbox), cbox_width, 26);
 
     cboxSignalId = gtk_signal_connect (GTK_OBJECT (cbox), "changed", G_CALLBACK (cbox_changed_cb), NULL);
+    // cbox_changed_cb (GTK_WIDGET (cbox), NULL);
 
     cell = gtk_cell_renderer_text_new();
     gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (cbox), cell, TRUE);
     gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (cbox), cell, "text", 0, NULL);
 
+
+
 #if GTK_CHECK_VERSION(2,16,0)
 
     // GdkPixbuf *pixbuf;
@@ -464,6 +482,10 @@ GtkWidget* contacts_searchbar_new ()
 
     g_free (tooltip_text);
 
+
+    // current_addressbook = gtk_combo_box_get_active_text (GTK_COMBO_BOX (cbox));
+    // set_current_addressbook (current_addressbook);
+
     return ret;
 }
 
