@@ -818,6 +818,22 @@ dbus_transfert (const callable_obj_t * c)
     }
 }
 
+void
+dbus_attended_transfer (const callable_obj_t *transfer, const callable_obj_t *target)
+{
+    DEBUG("DBUS: Attended tramsfer %s to %s", transfer->_callID, target->_callID);
+
+    GError *error = NULL;
+    org_sflphone_SFLphone_CallManager_attended_transfer (callManagerProxy, transfer->_callID,
+        target->_callID, &error);
+
+    if(error) {
+        ERROR("Failed to call transfer() on CallManager: %s",
+              error->message);
+        g_error_free(error);
+    }
+}
+
 void
 dbus_accept (const callable_obj_t * c)
 {
@@ -859,8 +875,6 @@ dbus_refuse (const callable_obj_t * c)
 void
 dbus_place_call (const callable_obj_t * c)
 {
-    DEBUG ("dbus_place_call %s\n", c->_callID);
-
     GError *error = NULL;
     org_sflphone_SFLphone_CallManager_place_call (callManagerProxy, c->_accountID,
             c->_callID, c->_peer_number, &error);
