@@ -1,5 +1,5 @@
 /* $Id: os_core_symbian.cpp 2853 2009-08-05 10:58:02Z bennylp $ */
-/* 
+/*
  * Copyright (C) 2008-2009 Teluu Inc. (http://www.teluu.com)
  * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
  *
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *  Additional permission under GNU GPL version 3 section 7:
  *
@@ -46,15 +46,14 @@
 #define DUMMY_MUTEX	    ((pj_mutex_t*)101)
 #define DUMMY_SEMAPHORE	    ((pj_sem_t*)102)
 #define THIS_FILE	    "os_core_symbian.c"
- 
+
 /*
  * Note:
  *
  * The Symbian implementation does not support threading!
- */ 
+ */
 
-struct pj_thread_t
-{
+struct pj_thread_t {
     char	    obj_name[PJ_MAX_OBJ_NAME];
     void	   *tls_values[PJ_MAX_TLS];
 
@@ -68,13 +67,11 @@ struct pj_thread_t
 
 } main_thread;
 
-struct pj_atomic_t
-{
+struct pj_atomic_t {
     pj_atomic_value_t	value;
 };
 
-struct pj_sem_t
-{
+struct pj_sem_t {
     int value;
     int max;
 };
@@ -84,7 +81,7 @@ static int tls_vars[PJ_MAX_TLS];
 
 /* atexit handlers */
 static unsigned atexit_count;
-static void (*atexit_func[32])(void);
+static void (*atexit_func[32]) (void);
 
 
 
@@ -95,7 +92,7 @@ static void (*atexit_func[32])(void);
 //
 
 CPjTimeoutTimer::CPjTimeoutTimer()
-: CActive(PJ_SYMBIAN_TIMER_PRIORITY), hasTimedOut_(PJ_FALSE)
+        : CActive (PJ_SYMBIAN_TIMER_PRIORITY), hasTimedOut_ (PJ_FALSE)
 {
 }
 
@@ -109,27 +106,27 @@ void CPjTimeoutTimer::ConstructL()
 {
     hasTimedOut_ = PJ_FALSE;
     timer_.CreateLocal();
-    CActiveScheduler::Add(this);
+    CActiveScheduler::Add (this);
 }
 
 CPjTimeoutTimer *CPjTimeoutTimer::NewL()
 {
     CPjTimeoutTimer *self = new CPjTimeoutTimer;
-    CleanupStack::PushL(self);
+    CleanupStack::PushL (self);
 
     self->ConstructL();
 
-    CleanupStack::Pop(self);
+    CleanupStack::Pop (self);
     return self;
 
 }
 
-void CPjTimeoutTimer::StartTimer(TUint miliSeconds)
+void CPjTimeoutTimer::StartTimer (TUint miliSeconds)
 {
     Cancel();
 
     hasTimedOut_ = PJ_FALSE;
-    timer_.After(iStatus, miliSeconds * 1000);
+    timer_.After (iStatus, miliSeconds * 1000);
     SetActive();
 }
 
@@ -148,9 +145,9 @@ void CPjTimeoutTimer::DoCancel()
     timer_.Cancel();
 }
 
-TInt CPjTimeoutTimer::RunError(TInt aError)
+TInt CPjTimeoutTimer::RunError (TInt aError)
 {
-    PJ_UNUSED_ARG(aError);
+    PJ_UNUSED_ARG (aError);
     return KErrNone;
 }
 
@@ -162,16 +159,16 @@ TInt CPjTimeoutTimer::RunError(TInt aError)
 //
 
 PjSymbianOS::PjSymbianOS()
-: isConnectionUp_(false),
-  isSocketServInitialized_(false), isResolverInitialized_(false),
-  console_(NULL), selectTimeoutTimer_(NULL),
-  appSocketServ_(NULL), appConnection_(NULL), appHostResolver_(NULL),
-  appHostResolver6_(NULL)
+        : isConnectionUp_ (false),
+        isSocketServInitialized_ (false), isResolverInitialized_ (false),
+        console_ (NULL), selectTimeoutTimer_ (NULL),
+        appSocketServ_ (NULL), appConnection_ (NULL), appHostResolver_ (NULL),
+        appHostResolver6_ (NULL)
 {
 }
 
 // Set parameters
-void PjSymbianOS::SetParameters(pj_symbianos_params *params) 
+void PjSymbianOS::SetParameters (pj_symbianos_params *params)
 {
     appSocketServ_ = (RSocketServ*) params->rsocketserv;
     appConnection_ = (RConnection*) params->rconnection;
@@ -195,9 +192,9 @@ TInt PjSymbianOS::Initialize()
     selectTimeoutTimer_ = CPjTimeoutTimer::NewL();
 
 #if 0
-    pj_assert(console_ == NULL);
-    TRAPD(err, console_ = Console::NewL(_L("PJLIB"), 
-				        TSize(KConsFullScreen,KConsFullScreen)));
+    pj_assert (console_ == NULL);
+    TRAPD (err, console_ = Console::NewL (_L ("PJLIB"),
+                                          TSize (KConsFullScreen,KConsFullScreen)));
     return err;
 #endif
 
@@ -205,44 +202,47 @@ TInt PjSymbianOS::Initialize()
      * in the parameters
      */
     if (!isSocketServInitialized_ && appSocketServ_ == NULL) {
-	err = socketServ_.Connect();
-	if (err != KErrNone)
-	    goto on_error;
+        err = socketServ_.Connect();
 
-	isSocketServInitialized_ = true;
+        if (err != KErrNone)
+            goto on_error;
+
+        isSocketServInitialized_ = true;
     }
 
     if (!isResolverInitialized_) {
-    	if (appHostResolver_ == NULL) {
-    	    if (Connection())
-    	    	err = hostResolver_.Open(SocketServ(), KAfInet, KSockStream,
-    	    			     	 *Connection());
-    	    else
-	    	err = hostResolver_.Open(SocketServ(), KAfInet, KSockStream);
-    	
-	    if (err != KErrNone)
-	    	goto on_error;
-    	}
-    	
+        if (appHostResolver_ == NULL) {
+            if (Connection())
+                err = hostResolver_.Open (SocketServ(), KAfInet, KSockStream,
+                                          *Connection());
+            else
+                err = hostResolver_.Open (SocketServ(), KAfInet, KSockStream);
+
+            if (err != KErrNone)
+                goto on_error;
+        }
+
 #if defined(PJ_HAS_IPV6) && PJ_HAS_IPV6!=0
-    	if (appHostResolver6_ == NULL) {
-    	    if (Connection())
-    	    	err = hostResolver6_.Open(SocketServ(), KAfInet6, KSockStream,
-    	    			     	  *Connection());
-    	    else
-	    	err = hostResolver6_.Open(SocketServ(), KAfInet6, KSockStream);
-    	
-	    if (err != KErrNone)
-	    	goto on_error;
-    	}
+
+        if (appHostResolver6_ == NULL) {
+            if (Connection())
+                err = hostResolver6_.Open (SocketServ(), KAfInet6, KSockStream,
+                                           *Connection());
+            else
+                err = hostResolver6_.Open (SocketServ(), KAfInet6, KSockStream);
+
+            if (err != KErrNone)
+                goto on_error;
+        }
+
 #endif
-    	
-    	
-	isResolverInitialized_ = true;
+
+
+        isResolverInitialized_ = true;
     }
 
     isConnectionUp_ = true;
-    
+
     return KErrNone;
 
 on_error:
@@ -254,18 +254,18 @@ on_error:
 void PjSymbianOS::Shutdown()
 {
     isConnectionUp_ = false;
-    
+
     if (isResolverInitialized_) {
-		hostResolver_.Close();
+        hostResolver_.Close();
 #if defined(PJ_HAS_IPV6) && PJ_HAS_IPV6!=0
-    	hostResolver6_.Close();
+        hostResolver6_.Close();
 #endif
-    	isResolverInitialized_ = false;
+        isResolverInitialized_ = false;
     }
 
     if (isSocketServInitialized_) {
-	socketServ_.Close();
-	isSocketServInitialized_ = false;
+        socketServ_.Close();
+        isSocketServInitialized_ = false;
     }
 
     delete console_;
@@ -273,7 +273,7 @@ void PjSymbianOS::Shutdown()
 
     delete selectTimeoutTimer_;
     selectTimeoutTimer_ = NULL;
-    
+
     appSocketServ_ = NULL;
     appConnection_ = NULL;
     appHostResolver_ = NULL;
@@ -281,24 +281,24 @@ void PjSymbianOS::Shutdown()
 }
 
 // Convert to Unicode
-TInt PjSymbianOS::ConvertToUnicode(TDes16 &aUnicode, const TDesC8 &aForeign)
+TInt PjSymbianOS::ConvertToUnicode (TDes16 &aUnicode, const TDesC8 &aForeign)
 {
 #if 0
-    pj_assert(conv_ != NULL);
-    return conv_->ConvertToUnicode(aUnicode, aForeign, convToUnicodeState_);
+    pj_assert (conv_ != NULL);
+    return conv_->ConvertToUnicode (aUnicode, aForeign, convToUnicodeState_);
 #else
-    return CnvUtfConverter::ConvertToUnicodeFromUtf8(aUnicode, aForeign);
+    return CnvUtfConverter::ConvertToUnicodeFromUtf8 (aUnicode, aForeign);
 #endif
 }
 
 // Convert from Unicode
-TInt PjSymbianOS::ConvertFromUnicode(TDes8 &aForeign, const TDesC16 &aUnicode)
+TInt PjSymbianOS::ConvertFromUnicode (TDes8 &aForeign, const TDesC16 &aUnicode)
 {
 #if 0
-    pj_assert(conv_ != NULL);
-    return conv_->ConvertFromUnicode(aForeign, aUnicode, convToAnsiState_);
+    pj_assert (conv_ != NULL);
+    return conv_->ConvertFromUnicode (aForeign, aUnicode, convToAnsiState_);
 #else
-    return CnvUtfConverter::ConvertFromUnicodeToUtf8(aForeign, aUnicode);
+    return CnvUtfConverter::ConvertFromUnicodeToUtf8 (aForeign, aUnicode);
 #endif
 }
 
@@ -308,25 +308,25 @@ TInt PjSymbianOS::ConvertFromUnicode(TDes8 &aForeign, const TDesC16 &aUnicode)
 // PJLIB os.h implementation
 //
 
-PJ_DEF(pj_uint32_t) pj_getpid(void)
+PJ_DEF (pj_uint32_t) pj_getpid (void)
 {
     return 0;
 }
 
 
 /* Set Symbian specific parameters */
-PJ_DEF(pj_status_t) pj_symbianos_set_params(pj_symbianos_params *prm) 
+PJ_DEF (pj_status_t) pj_symbianos_set_params (pj_symbianos_params *prm)
 {
-    PJ_ASSERT_RETURN(prm != NULL, PJ_EINVAL);
-    PjSymbianOS::Instance()->SetParameters(prm);
+    PJ_ASSERT_RETURN (prm != NULL, PJ_EINVAL);
+    PjSymbianOS::Instance()->SetParameters (prm);
     return PJ_SUCCESS;
 }
 
 
 /* Set connection status */
-PJ_DEF(void) pj_symbianos_set_connection_status(pj_bool_t up)
+PJ_DEF (void) pj_symbianos_set_connection_status (pj_bool_t up)
 {
-    PjSymbianOS::Instance()->SetConnectionStatus(up != 0);
+    PjSymbianOS::Instance()->SetConnectionStatus (up != 0);
 }
 
 
@@ -334,33 +334,35 @@ PJ_DEF(void) pj_symbianos_set_connection_status(pj_bool_t up)
  * pj_init(void).
  * Init PJLIB!
  */
-PJ_DEF(pj_status_t) pj_init(void)
+PJ_DEF (pj_status_t) pj_init (void)
 {
-	char stack_ptr;
+    char stack_ptr;
     pj_status_t status;
-    
-    pj_ansi_strcpy(main_thread.obj_name, "pjthread");
+
+    pj_ansi_strcpy (main_thread.obj_name, "pjthread");
 
     // Init main thread
-    pj_memset(&main_thread, 0, sizeof(main_thread));
+    pj_memset (&main_thread, 0, sizeof (main_thread));
 
     // Initialize PjSymbianOS instance
     PjSymbianOS *os = PjSymbianOS::Instance();
 
-    PJ_LOG(4,(THIS_FILE, "Initializing PJLIB for Symbian OS.."));
+    PJ_LOG (4, (THIS_FILE, "Initializing PJLIB for Symbian OS.."));
 
-    TInt err; 
+    TInt err;
     err = os->Initialize();
+
     if (err != KErrNone)
-    	return PJ_RETURN_OS_ERROR(err);
+        return PJ_RETURN_OS_ERROR (err);
 
     /* Init logging */
     pj_log_init();
 
-    /* Initialize exception ID for the pool. 
+    /* Initialize exception ID for the pool.
      * Must do so after critical section is configured.
-     */ 
-    status = pj_exception_id_alloc("PJLIB/No memory", &PJ_NO_MEMORY_EXCEPTION);
+     */
+    status = pj_exception_id_alloc ("PJLIB/No memory", &PJ_NO_MEMORY_EXCEPTION);
+
     if (status != PJ_SUCCESS)
         goto on_error;
 
@@ -372,19 +374,19 @@ PJ_DEF(pj_status_t) pj_init(void)
     stack_ptr = '\0';
 #endif
 
-    PJ_LOG(5,(THIS_FILE, "PJLIB initialized."));
+    PJ_LOG (5, (THIS_FILE, "PJLIB initialized."));
     return PJ_SUCCESS;
 
 on_error:
     pj_shutdown();
-    return PJ_RETURN_OS_ERROR(err);
+    return PJ_RETURN_OS_ERROR (err);
 }
 
 
-PJ_DEF(pj_status_t) pj_atexit(pj_exit_callback func)
+PJ_DEF (pj_status_t) pj_atexit (pj_exit_callback func)
 {
-    if (atexit_count >= PJ_ARRAY_SIZE(atexit_func))
-	return PJ_ETOOMANY;
+    if (atexit_count >= PJ_ARRAY_SIZE (atexit_func))
+        return PJ_ETOOMANY;
 
     atexit_func[atexit_count++] = func;
     return PJ_SUCCESS;
@@ -392,18 +394,18 @@ PJ_DEF(pj_status_t) pj_atexit(pj_exit_callback func)
 
 
 
-PJ_DEF(void) pj_shutdown(void)
+PJ_DEF (void) pj_shutdown (void)
 {
     /* Call atexit() functions */
     while (atexit_count > 0) {
-	(*atexit_func[atexit_count-1])();
-	--atexit_count;
+        (*atexit_func[atexit_count-1]) ();
+        --atexit_count;
     }
 
     /* Free exception ID */
     if (PJ_NO_MEMORY_EXCEPTION != -1) {
-	pj_exception_id_free(PJ_NO_MEMORY_EXCEPTION);
-	PJ_NO_MEMORY_EXCEPTION = -1;
+        pj_exception_id_free (PJ_NO_MEMORY_EXCEPTION);
+        PJ_NO_MEMORY_EXCEPTION = -1;
     }
 
     /* Clear static variables */
@@ -415,88 +417,88 @@ PJ_DEF(void) pj_shutdown(void)
 
 /////////////////////////////////////////////////////////////////////////////
 
-class CPollTimeoutTimer : public CActive 
+class CPollTimeoutTimer : public CActive
 {
-public:
-    static CPollTimeoutTimer* NewL(int msec, TInt prio);
-    ~CPollTimeoutTimer();
-    
-    virtual void RunL();
-    virtual void DoCancel();
+    public:
+        static CPollTimeoutTimer* NewL (int msec, TInt prio);
+        ~CPollTimeoutTimer();
 
-private:	
-    RTimer	     rtimer_;
-    
-    explicit CPollTimeoutTimer(TInt prio);
-    void ConstructL(int msec);
+        virtual void RunL();
+        virtual void DoCancel();
+
+    private:
+        RTimer	     rtimer_;
+
+        explicit CPollTimeoutTimer (TInt prio);
+        void ConstructL (int msec);
 };
 
-CPollTimeoutTimer::CPollTimeoutTimer(TInt prio)
-: CActive(prio)
+CPollTimeoutTimer::CPollTimeoutTimer (TInt prio)
+        : CActive (prio)
 {
 }
 
 
-CPollTimeoutTimer::~CPollTimeoutTimer() 
+CPollTimeoutTimer::~CPollTimeoutTimer()
 {
     rtimer_.Close();
 }
 
-void CPollTimeoutTimer::ConstructL(int msec) 
+void CPollTimeoutTimer::ConstructL (int msec)
 {
     rtimer_.CreateLocal();
-    CActiveScheduler::Add(this);
-    rtimer_.After(iStatus, msec*1000);
+    CActiveScheduler::Add (this);
+    rtimer_.After (iStatus, msec*1000);
     SetActive();
 }
 
-CPollTimeoutTimer* CPollTimeoutTimer::NewL(int msec, TInt prio) 
+CPollTimeoutTimer* CPollTimeoutTimer::NewL (int msec, TInt prio)
 {
-    CPollTimeoutTimer *self = new CPollTimeoutTimer(prio);
-    CleanupStack::PushL(self);
-    self->ConstructL(msec);    
-    CleanupStack::Pop(self);
+    CPollTimeoutTimer *self = new CPollTimeoutTimer (prio);
+    CleanupStack::PushL (self);
+    self->ConstructL (msec);
+    CleanupStack::Pop (self);
 
     return self;
 }
 
-void CPollTimeoutTimer::RunL() 
+void CPollTimeoutTimer::RunL()
 {
 }
 
-void CPollTimeoutTimer::DoCancel() 
+void CPollTimeoutTimer::DoCancel()
 {
-     rtimer_.Cancel();
+    rtimer_.Cancel();
 }
 
 
 /*
- * Wait the completion of any Symbian active objects. 
+ * Wait the completion of any Symbian active objects.
  */
-PJ_DEF(pj_bool_t) pj_symbianos_poll(int priority, int ms_timeout)
+PJ_DEF (pj_bool_t) pj_symbianos_poll (int priority, int ms_timeout)
 {
     CPollTimeoutTimer *timer = NULL;
-    
+
     if (priority==-1)
-    	priority = EPriorityNull;
-    
+        priority = EPriorityNull;
+
     if (ms_timeout >= 0) {
-    	timer = CPollTimeoutTimer::NewL(ms_timeout, priority);
+        timer = CPollTimeoutTimer::NewL (ms_timeout, priority);
     }
-    
-    PjSymbianOS::Instance()->WaitForActiveObjects(priority);
-    
+
+    PjSymbianOS::Instance()->WaitForActiveObjects (priority);
+
     if (timer) {
         bool timer_is_active = timer->IsActive();
-    
-	timer->Cancel();
-        
+
+        timer->Cancel();
+
         delete timer;
-        
-    	return timer_is_active ? PJ_TRUE : PJ_FALSE;
-    	
+
+        return timer_is_active ? PJ_TRUE : PJ_FALSE;
+
     } else {
-    	return PJ_TRUE;
+        return PJ_TRUE;
     }
 }
 
@@ -504,7 +506,7 @@ PJ_DEF(pj_bool_t) pj_symbianos_poll(int priority, int ms_timeout)
 /*
  * pj_thread_is_registered()
  */
-PJ_DEF(pj_bool_t) pj_thread_is_registered(void)
+PJ_DEF (pj_bool_t) pj_thread_is_registered (void)
 {
     return PJ_FALSE;
 }
@@ -513,9 +515,9 @@ PJ_DEF(pj_bool_t) pj_thread_is_registered(void)
 /*
  * Get thread priority value for the thread.
  */
-PJ_DEF(int) pj_thread_get_prio(pj_thread_t *thread)
+PJ_DEF (int) pj_thread_get_prio (pj_thread_t *thread)
 {
-    PJ_UNUSED_ARG(thread);
+    PJ_UNUSED_ARG (thread);
     return 1;
 }
 
@@ -523,10 +525,10 @@ PJ_DEF(int) pj_thread_get_prio(pj_thread_t *thread)
 /*
  * Set the thread priority.
  */
-PJ_DEF(pj_status_t) pj_thread_set_prio(pj_thread_t *thread,  int prio)
+PJ_DEF (pj_status_t) pj_thread_set_prio (pj_thread_t *thread,  int prio)
 {
-    PJ_UNUSED_ARG(thread);
-    PJ_UNUSED_ARG(prio);
+    PJ_UNUSED_ARG (thread);
+    PJ_UNUSED_ARG (prio);
     return PJ_SUCCESS;
 }
 
@@ -534,9 +536,9 @@ PJ_DEF(pj_status_t) pj_thread_set_prio(pj_thread_t *thread,  int prio)
 /*
  * Get the lowest priority value available on this system.
  */
-PJ_DEF(int) pj_thread_get_prio_min(pj_thread_t *thread)
+PJ_DEF (int) pj_thread_get_prio_min (pj_thread_t *thread)
 {
-    PJ_UNUSED_ARG(thread);
+    PJ_UNUSED_ARG (thread);
     return 1;
 }
 
@@ -544,9 +546,9 @@ PJ_DEF(int) pj_thread_get_prio_min(pj_thread_t *thread)
 /*
  * Get the highest priority value available on this system.
  */
-PJ_DEF(int) pj_thread_get_prio_max(pj_thread_t *thread)
+PJ_DEF (int) pj_thread_get_prio_max (pj_thread_t *thread)
 {
-    PJ_UNUSED_ARG(thread);
+    PJ_UNUSED_ARG (thread);
     return 1;
 }
 
@@ -554,22 +556,22 @@ PJ_DEF(int) pj_thread_get_prio_max(pj_thread_t *thread)
 /*
  * pj_thread_get_os_handle()
  */
-PJ_DEF(void*) pj_thread_get_os_handle(pj_thread_t *thread) 
+PJ_DEF (void*) pj_thread_get_os_handle (pj_thread_t *thread)
 {
-    PJ_UNUSED_ARG(thread);
+    PJ_UNUSED_ARG (thread);
     return NULL;
 }
 
 /*
  * pj_thread_register(..)
  */
-PJ_DEF(pj_status_t) pj_thread_register ( const char *cstr_thread_name,
-					 pj_thread_desc desc,
-                                         pj_thread_t **thread_ptr)
+PJ_DEF (pj_status_t) pj_thread_register (const char *cstr_thread_name,
+        pj_thread_desc desc,
+        pj_thread_t **thread_ptr)
 {
-    PJ_UNUSED_ARG(cstr_thread_name);
-    PJ_UNUSED_ARG(desc);
-    PJ_UNUSED_ARG(thread_ptr);
+    PJ_UNUSED_ARG (cstr_thread_name);
+    PJ_UNUSED_ARG (desc);
+    PJ_UNUSED_ARG (thread_ptr);
     return PJ_EINVALIDOP;
 }
 
@@ -577,21 +579,21 @@ PJ_DEF(pj_status_t) pj_thread_register ( const char *cstr_thread_name,
 /*
  * pj_thread_create(...)
  */
-PJ_DEF(pj_status_t) pj_thread_create( pj_pool_t *pool, 
-				      const char *thread_name,
-				      pj_thread_proc *proc, 
-				      void *arg,
-				      pj_size_t stack_size, 
-				      unsigned flags,
-				      pj_thread_t **ptr_thread)
+PJ_DEF (pj_status_t) pj_thread_create (pj_pool_t *pool,
+                                       const char *thread_name,
+                                       pj_thread_proc *proc,
+                                       void *arg,
+                                       pj_size_t stack_size,
+                                       unsigned flags,
+                                       pj_thread_t **ptr_thread)
 {
-    PJ_UNUSED_ARG(pool);
-    PJ_UNUSED_ARG(thread_name);
-    PJ_UNUSED_ARG(proc);
-    PJ_UNUSED_ARG(arg);
-    PJ_UNUSED_ARG(stack_size);
-    PJ_UNUSED_ARG(flags);
-    PJ_UNUSED_ARG(ptr_thread);
+    PJ_UNUSED_ARG (pool);
+    PJ_UNUSED_ARG (thread_name);
+    PJ_UNUSED_ARG (proc);
+    PJ_UNUSED_ARG (arg);
+    PJ_UNUSED_ARG (stack_size);
+    PJ_UNUSED_ARG (flags);
+    PJ_UNUSED_ARG (ptr_thread);
 
     /* Sorry mate, we don't support threading */
     return PJ_ENOTSUP;
@@ -600,25 +602,25 @@ PJ_DEF(pj_status_t) pj_thread_create( pj_pool_t *pool,
 /*
  * pj_thread-get_name()
  */
-PJ_DEF(const char*) pj_thread_get_name(pj_thread_t *p)
+PJ_DEF (const char*) pj_thread_get_name (pj_thread_t *p)
 {
-    pj_assert(p == &main_thread);
+    pj_assert (p == &main_thread);
     return p->obj_name;
 }
 
 /*
  * pj_thread_resume()
  */
-PJ_DEF(pj_status_t) pj_thread_resume(pj_thread_t *p)
+PJ_DEF (pj_status_t) pj_thread_resume (pj_thread_t *p)
 {
-    PJ_UNUSED_ARG(p);
+    PJ_UNUSED_ARG (p);
     return PJ_EINVALIDOP;
 }
 
 /*
  * pj_thread_this()
  */
-PJ_DEF(pj_thread_t*) pj_thread_this(void)
+PJ_DEF (pj_thread_t*) pj_thread_this (void)
 {
     return &main_thread;
 }
@@ -626,27 +628,27 @@ PJ_DEF(pj_thread_t*) pj_thread_this(void)
 /*
  * pj_thread_join()
  */
-PJ_DEF(pj_status_t) pj_thread_join(pj_thread_t *rec)
+PJ_DEF (pj_status_t) pj_thread_join (pj_thread_t *rec)
 {
-    PJ_UNUSED_ARG(rec);
+    PJ_UNUSED_ARG (rec);
     return PJ_EINVALIDOP;
 }
 
 /*
  * pj_thread_destroy()
  */
-PJ_DEF(pj_status_t) pj_thread_destroy(pj_thread_t *rec)
+PJ_DEF (pj_status_t) pj_thread_destroy (pj_thread_t *rec)
 {
-    PJ_UNUSED_ARG(rec);
+    PJ_UNUSED_ARG (rec);
     return PJ_EINVALIDOP;
 }
 
 /*
  * pj_thread_sleep()
  */
-PJ_DEF(pj_status_t) pj_thread_sleep(unsigned msec)
+PJ_DEF (pj_status_t) pj_thread_sleep (unsigned msec)
 {
-    User::After(msec*1000);
+    User::After (msec*1000);
 
     return PJ_SUCCESS;
 }
@@ -657,18 +659,18 @@ PJ_DEF(pj_status_t) pj_thread_sleep(unsigned msec)
  * pj_thread_local_alloc()
  */
 
-PJ_DEF(pj_status_t) pj_thread_local_alloc(long *index)
+PJ_DEF (pj_status_t) pj_thread_local_alloc (long *index)
 {
     unsigned i;
 
     /* Find unused TLS variable */
-    for (i=0; i<PJ_ARRAY_SIZE(tls_vars); ++i) {
-	if (tls_vars[i] == 0)
-	    break;
+    for (i=0; i<PJ_ARRAY_SIZE (tls_vars); ++i) {
+        if (tls_vars[i] == 0)
+            break;
     }
 
-    if (i == PJ_ARRAY_SIZE(tls_vars))
-	return PJ_ETOOMANY;
+    if (i == PJ_ARRAY_SIZE (tls_vars))
+        return PJ_ETOOMANY;
 
     tls_vars[i] = 1;
     *index = i;
@@ -679,10 +681,10 @@ PJ_DEF(pj_status_t) pj_thread_local_alloc(long *index)
 /*
  * pj_thread_local_free()
  */
-PJ_DEF(void) pj_thread_local_free(long index)
+PJ_DEF (void) pj_thread_local_free (long index)
 {
-    PJ_ASSERT_ON_FAIL(index >= 0 && index < (int)PJ_ARRAY_SIZE(tls_vars) &&
-		     tls_vars[index] != 0, return);
+    PJ_ASSERT_ON_FAIL (index >= 0 && index < (int) PJ_ARRAY_SIZE (tls_vars) &&
+                       tls_vars[index] != 0, return);
 
     tls_vars[index] = 0;
 }
@@ -691,12 +693,12 @@ PJ_DEF(void) pj_thread_local_free(long index)
 /*
  * pj_thread_local_set()
  */
-PJ_DEF(pj_status_t) pj_thread_local_set(long index, void *value)
+PJ_DEF (pj_status_t) pj_thread_local_set (long index, void *value)
 {
     pj_thread_t *rec = pj_thread_this();
 
-    PJ_ASSERT_RETURN(index >= 0 && index < (int)PJ_ARRAY_SIZE(tls_vars) &&
-		     tls_vars[index] != 0, PJ_EINVAL);
+    PJ_ASSERT_RETURN (index >= 0 && index < (int) PJ_ARRAY_SIZE (tls_vars) &&
+                      tls_vars[index] != 0, PJ_EINVAL);
 
     rec->tls_values[index] = value;
     return PJ_SUCCESS;
@@ -705,12 +707,12 @@ PJ_DEF(pj_status_t) pj_thread_local_set(long index, void *value)
 /*
  * pj_thread_local_get()
  */
-PJ_DEF(void*) pj_thread_local_get(long index)
+PJ_DEF (void*) pj_thread_local_get (long index)
 {
     pj_thread_t *rec = pj_thread_this();
 
-    PJ_ASSERT_RETURN(index >= 0 && index < (int)PJ_ARRAY_SIZE(tls_vars) &&
-		     tls_vars[index] != 0, NULL);
+    PJ_ASSERT_RETURN (index >= 0 && index < (int) PJ_ARRAY_SIZE (tls_vars) &&
+                      tls_vars[index] != 0, NULL);
 
     return rec->tls_values[index];
 }
@@ -720,11 +722,11 @@ PJ_DEF(void*) pj_thread_local_get(long index)
 /*
  * Create atomic variable.
  */
-PJ_DEF(pj_status_t) pj_atomic_create( pj_pool_t *pool, 
-				      pj_atomic_value_t initial,
-				      pj_atomic_t **atomic )
+PJ_DEF (pj_status_t) pj_atomic_create (pj_pool_t *pool,
+                                       pj_atomic_value_t initial,
+                                       pj_atomic_t **atomic)
 {
-    *atomic = (pj_atomic_t*)pj_pool_alloc(pool, sizeof(struct pj_atomic_t));
+    *atomic = (pj_atomic_t*) pj_pool_alloc (pool, sizeof (struct pj_atomic_t));
     (*atomic)->value = initial;
     return PJ_SUCCESS;
 }
@@ -733,9 +735,9 @@ PJ_DEF(pj_status_t) pj_atomic_create( pj_pool_t *pool,
 /*
  * Destroy atomic variable.
  */
-PJ_DEF(pj_status_t) pj_atomic_destroy( pj_atomic_t *atomic_var )
+PJ_DEF (pj_status_t) pj_atomic_destroy (pj_atomic_t *atomic_var)
 {
-    PJ_UNUSED_ARG(atomic_var);
+    PJ_UNUSED_ARG (atomic_var);
     return PJ_SUCCESS;
 }
 
@@ -743,8 +745,8 @@ PJ_DEF(pj_status_t) pj_atomic_destroy( pj_atomic_t *atomic_var )
 /*
  * Set the value of an atomic type, and return the previous value.
  */
-PJ_DEF(void) pj_atomic_set( pj_atomic_t *atomic_var, 
-			    pj_atomic_value_t value)
+PJ_DEF (void) pj_atomic_set (pj_atomic_t *atomic_var,
+                             pj_atomic_value_t value)
 {
     atomic_var->value = value;
 }
@@ -753,7 +755,7 @@ PJ_DEF(void) pj_atomic_set( pj_atomic_t *atomic_var,
 /*
  * Get the value of an atomic type.
  */
-PJ_DEF(pj_atomic_value_t) pj_atomic_get(pj_atomic_t *atomic_var)
+PJ_DEF (pj_atomic_value_t) pj_atomic_get (pj_atomic_t *atomic_var)
 {
     return atomic_var->value;
 }
@@ -762,7 +764,7 @@ PJ_DEF(pj_atomic_value_t) pj_atomic_get(pj_atomic_t *atomic_var)
 /*
  * Increment the value of an atomic type.
  */
-PJ_DEF(void) pj_atomic_inc(pj_atomic_t *atomic_var)
+PJ_DEF (void) pj_atomic_inc (pj_atomic_t *atomic_var)
 {
     ++atomic_var->value;
 }
@@ -771,7 +773,7 @@ PJ_DEF(void) pj_atomic_inc(pj_atomic_t *atomic_var)
 /*
  * Increment the value of an atomic type and get the result.
  */
-PJ_DEF(pj_atomic_value_t) pj_atomic_inc_and_get(pj_atomic_t *atomic_var)
+PJ_DEF (pj_atomic_value_t) pj_atomic_inc_and_get (pj_atomic_t *atomic_var)
 {
     return ++atomic_var->value;
 }
@@ -780,16 +782,16 @@ PJ_DEF(pj_atomic_value_t) pj_atomic_inc_and_get(pj_atomic_t *atomic_var)
 /*
  * Decrement the value of an atomic type.
  */
-PJ_DEF(void) pj_atomic_dec(pj_atomic_t *atomic_var)
+PJ_DEF (void) pj_atomic_dec (pj_atomic_t *atomic_var)
 {
     --atomic_var->value;
-}	
+}
 
 
 /*
  * Decrement the value of an atomic type and get the result.
  */
-PJ_DEF(pj_atomic_value_t) pj_atomic_dec_and_get(pj_atomic_t *atomic_var)
+PJ_DEF (pj_atomic_value_t) pj_atomic_dec_and_get (pj_atomic_t *atomic_var)
 {
     return --atomic_var->value;
 }
@@ -798,8 +800,8 @@ PJ_DEF(pj_atomic_value_t) pj_atomic_dec_and_get(pj_atomic_t *atomic_var)
 /*
  * Add a value to an atomic type.
  */
-PJ_DEF(void) pj_atomic_add( pj_atomic_t *atomic_var,
-			    pj_atomic_value_t value)
+PJ_DEF (void) pj_atomic_add (pj_atomic_t *atomic_var,
+                             pj_atomic_value_t value)
 {
     atomic_var->value += value;
 }
@@ -808,8 +810,8 @@ PJ_DEF(void) pj_atomic_add( pj_atomic_t *atomic_var,
 /*
  * Add a value to an atomic type and get the result.
  */
-PJ_DEF(pj_atomic_value_t) pj_atomic_add_and_get( pj_atomic_t *atomic_var,
-			                         pj_atomic_value_t value)
+PJ_DEF (pj_atomic_value_t) pj_atomic_add_and_get (pj_atomic_t *atomic_var,
+        pj_atomic_value_t value)
 {
     atomic_var->value += value;
     return atomic_var->value;
@@ -819,14 +821,14 @@ PJ_DEF(pj_atomic_value_t) pj_atomic_add_and_get( pj_atomic_t *atomic_var,
 
 /////////////////////////////////////////////////////////////////////////////
 
-PJ_DEF(pj_status_t) pj_mutex_create( pj_pool_t *pool, 
-                                     const char *name,
-				     int type, 
-                                     pj_mutex_t **mutex)
+PJ_DEF (pj_status_t) pj_mutex_create (pj_pool_t *pool,
+                                      const char *name,
+                                      int type,
+                                      pj_mutex_t **mutex)
 {
-    PJ_UNUSED_ARG(pool);
-    PJ_UNUSED_ARG(name);
-    PJ_UNUSED_ARG(type);
+    PJ_UNUSED_ARG (pool);
+    PJ_UNUSED_ARG (name);
+    PJ_UNUSED_ARG (type);
 
     *mutex = DUMMY_MUTEX;
     return PJ_SUCCESS;
@@ -835,55 +837,55 @@ PJ_DEF(pj_status_t) pj_mutex_create( pj_pool_t *pool,
 /*
  * pj_mutex_create_simple()
  */
-PJ_DEF(pj_status_t) pj_mutex_create_simple( pj_pool_t *pool, 
-                                            const char *name,
-					    pj_mutex_t **mutex )
+PJ_DEF (pj_status_t) pj_mutex_create_simple (pj_pool_t *pool,
+        const char *name,
+        pj_mutex_t **mutex)
 {
-    return pj_mutex_create(pool, name, PJ_MUTEX_SIMPLE, mutex);
+    return pj_mutex_create (pool, name, PJ_MUTEX_SIMPLE, mutex);
 }
 
 
-PJ_DEF(pj_status_t) pj_mutex_create_recursive( pj_pool_t *pool,
-					       const char *name,
-					       pj_mutex_t **mutex )
+PJ_DEF (pj_status_t) pj_mutex_create_recursive (pj_pool_t *pool,
+        const char *name,
+        pj_mutex_t **mutex)
 {
-    return pj_mutex_create(pool, name, PJ_MUTEX_RECURSE, mutex);
+    return pj_mutex_create (pool, name, PJ_MUTEX_RECURSE, mutex);
 }
 
 
 /*
  * pj_mutex_lock()
  */
-PJ_DEF(pj_status_t) pj_mutex_lock(pj_mutex_t *mutex)
+PJ_DEF (pj_status_t) pj_mutex_lock (pj_mutex_t *mutex)
 {
-    pj_assert(mutex == DUMMY_MUTEX);
+    pj_assert (mutex == DUMMY_MUTEX);
     return PJ_SUCCESS;
 }
 
 /*
  * pj_mutex_trylock()
  */
-PJ_DEF(pj_status_t) pj_mutex_trylock(pj_mutex_t *mutex)
+PJ_DEF (pj_status_t) pj_mutex_trylock (pj_mutex_t *mutex)
 {
-    pj_assert(mutex == DUMMY_MUTEX);
+    pj_assert (mutex == DUMMY_MUTEX);
     return PJ_SUCCESS;
 }
 
 /*
  * pj_mutex_unlock()
  */
-PJ_DEF(pj_status_t) pj_mutex_unlock(pj_mutex_t *mutex)
+PJ_DEF (pj_status_t) pj_mutex_unlock (pj_mutex_t *mutex)
 {
-    pj_assert(mutex == DUMMY_MUTEX);
+    pj_assert (mutex == DUMMY_MUTEX);
     return PJ_SUCCESS;
 }
 
 /*
  * pj_mutex_destroy()
  */
-PJ_DEF(pj_status_t) pj_mutex_destroy(pj_mutex_t *mutex)
+PJ_DEF (pj_status_t) pj_mutex_destroy (pj_mutex_t *mutex)
 {
-    pj_assert(mutex == DUMMY_MUTEX);
+    pj_assert (mutex == DUMMY_MUTEX);
     return PJ_SUCCESS;
 }
 
@@ -900,7 +902,7 @@ PJ_DEF(pj_status_t) pj_mutex_destroy(pj_mutex_t *mutex)
 /*
  * Enter critical section.
  */
-PJ_DEF(void) pj_enter_critical_section(void)
+PJ_DEF (void) pj_enter_critical_section (void)
 {
     /* Nothing to do */
 }
@@ -909,7 +911,7 @@ PJ_DEF(void) pj_enter_critical_section(void)
 /*
  * Leave critical section.
  */
-PJ_DEF(void) pj_leave_critical_section(void)
+PJ_DEF (void) pj_leave_critical_section (void)
 {
     /* Nothing to do */
 }
@@ -920,17 +922,17 @@ PJ_DEF(void) pj_leave_critical_section(void)
 /*
  * Create semaphore.
  */
-PJ_DEF(pj_status_t) pj_sem_create( pj_pool_t *pool, 
-                                   const char *name,
-				   unsigned initial, 
-                                   unsigned max,
-				   pj_sem_t **p_sem)
+PJ_DEF (pj_status_t) pj_sem_create (pj_pool_t *pool,
+                                    const char *name,
+                                    unsigned initial,
+                                    unsigned max,
+                                    pj_sem_t **p_sem)
 {
     pj_sem_t *sem;
- 
-    PJ_UNUSED_ARG(name);
 
-    sem = (pj_sem_t*) pj_pool_zalloc(pool, sizeof(pj_sem_t));
+    PJ_UNUSED_ARG (name);
+
+    sem = (pj_sem_t*) pj_pool_zalloc (pool, sizeof (pj_sem_t));
     sem->value = initial;
     sem->max = max;
 
@@ -943,14 +945,14 @@ PJ_DEF(pj_status_t) pj_sem_create( pj_pool_t *pool,
 /*
  * Wait for semaphore.
  */
-PJ_DEF(pj_status_t) pj_sem_wait(pj_sem_t *sem)
+PJ_DEF (pj_status_t) pj_sem_wait (pj_sem_t *sem)
 {
     if (sem->value > 0) {
-	sem->value--;
-	return PJ_SUCCESS;
+        sem->value--;
+        return PJ_SUCCESS;
     } else {
-	pj_assert(!"Unexpected!");
-	return PJ_EINVALIDOP;
+        pj_assert (!"Unexpected!");
+        return PJ_EINVALIDOP;
     }
 }
 
@@ -958,14 +960,14 @@ PJ_DEF(pj_status_t) pj_sem_wait(pj_sem_t *sem)
 /*
  * Try wait for semaphore.
  */
-PJ_DEF(pj_status_t) pj_sem_trywait(pj_sem_t *sem)
+PJ_DEF (pj_status_t) pj_sem_trywait (pj_sem_t *sem)
 {
     if (sem->value > 0) {
-	sem->value--;
-	return PJ_SUCCESS;
+        sem->value--;
+        return PJ_SUCCESS;
     } else {
-	pj_assert(!"Unexpected!");
-	return PJ_EINVALIDOP;
+        pj_assert (!"Unexpected!");
+        return PJ_EINVALIDOP;
     }
 }
 
@@ -973,7 +975,7 @@ PJ_DEF(pj_status_t) pj_sem_trywait(pj_sem_t *sem)
 /*
  * Release semaphore.
  */
-PJ_DEF(pj_status_t) pj_sem_post(pj_sem_t *sem)
+PJ_DEF (pj_status_t) pj_sem_post (pj_sem_t *sem)
 {
     sem->value++;
     return PJ_SUCCESS;
@@ -983,56 +985,56 @@ PJ_DEF(pj_status_t) pj_sem_post(pj_sem_t *sem)
 /*
  * Destroy semaphore.
  */
-PJ_DEF(pj_status_t) pj_sem_destroy(pj_sem_t *sem)
+PJ_DEF (pj_status_t) pj_sem_destroy (pj_sem_t *sem)
 {
-    PJ_UNUSED_ARG(sem);
+    PJ_UNUSED_ARG (sem);
     return PJ_SUCCESS;
 }
 
 
 #if defined(PJ_OS_HAS_CHECK_STACK) && PJ_OS_HAS_CHECK_STACK != 0
 /*
- * The implementation of stack checking. 
+ * The implementation of stack checking.
  */
-PJ_DEF(void) pj_thread_check_stack(const char *file, int line)
+PJ_DEF (void) pj_thread_check_stack (const char *file, int line)
 {
     char stk_ptr;
     pj_uint32_t usage;
     pj_thread_t *thread = pj_thread_this();
 
-    pj_assert(thread);
+    pj_assert (thread);
 
     /* Calculate current usage. */
     usage = (&stk_ptr > thread->stk_start) ? &stk_ptr - thread->stk_start :
-		thread->stk_start - &stk_ptr;
+            thread->stk_start - &stk_ptr;
 
     /* Assert if stack usage is dangerously high. */
-    pj_assert("STACK OVERFLOW!! " && (usage <= thread->stk_size - 128));
+    pj_assert ("STACK OVERFLOW!! " && (usage <= thread->stk_size - 128));
 
     /* Keep statistic. */
     if (usage > thread->stk_max_usage) {
-	thread->stk_max_usage = usage;
-	thread->caller_file = file;
-	thread->caller_line = line;
+        thread->stk_max_usage = usage;
+        thread->caller_file = file;
+        thread->caller_line = line;
     }
 }
 
 /*
- * Get maximum stack usage statistic. 
+ * Get maximum stack usage statistic.
  */
-PJ_DEF(pj_uint32_t) pj_thread_get_stack_max_usage(pj_thread_t *thread)
+PJ_DEF (pj_uint32_t) pj_thread_get_stack_max_usage (pj_thread_t *thread)
 {
     return thread->stk_max_usage;
 }
 
 /*
- * Dump thread stack status. 
+ * Dump thread stack status.
  */
-PJ_DEF(pj_status_t) pj_thread_get_stack_info(pj_thread_t *thread,
-					     const char **file,
-					     int *line)
+PJ_DEF (pj_status_t) pj_thread_get_stack_info (pj_thread_t *thread,
+        const char **file,
+        int *line)
 {
-    pj_assert(thread);
+    pj_assert (thread);
 
     *file = thread->caller_file;
     *line = thread->caller_line;
