@@ -10,24 +10,20 @@ int utilspp::PrivateMembers::mNbElements = 0;
 utilspp::PrivateMembers::LifetimeTracker::LifetimeTracker (unsigned int
         longevity)
         :
-        mLongevity (longevity)
-{}
+        mLongevity (longevity) {}
 
-utilspp::PrivateMembers::LifetimeTracker::~LifetimeTracker()
-{}
+utilspp::PrivateMembers::LifetimeTracker::~LifetimeTracker() {}
 
 bool
 utilspp::PrivateMembers::LifetimeTracker::compare (
     const LifetimeTracker *l,
     const LifetimeTracker *r
-)
-{
+) {
     return l->mLongevity < r->mLongevity;
 }
 
 void
-utilspp::PrivateMembers::atExitFunc()
-{
+utilspp::PrivateMembers::atExitFunc() {
     assert ( (mTrackerArray != NULL) &&
              (mNbElements > 0));
 
