@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -30,6 +30,7 @@
  */
 
 #include "audiolayer.h"
+#include "manager.h"
 
 void AudioLayer::flushMain (void)
 {
@@ -83,4 +84,18 @@ int AudioLayer::putMain (void *buffer, int toCopy, CallID call_id)
     return 0;
 }
 
+void AudioLayer::notifyincomingCall()
+{
+    // Notify (with a beep) an incoming call when there is already a call
+    if (Manager::instance().incomingCallWaiting()) {
+        _countNotificationTime += _time->getSecond();
+        int countTimeModulo = _countNotificationTime % 5000;
+
+        if ( (countTimeModulo - _countNotificationTime) < 0) {
+            Manager::instance().notificationIncomingCall();
+        }
+
+        _countNotificationTime = countTimeModulo;
+    }
+}
 
