@@ -53,12 +53,11 @@
 #include <cc++/numbers.h> // ost::Time
 
 #include <fstream>
-
 namespace sfl
 {
 
 // class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public AudioRtpRecordHandler, public ost::TRTPSessionBase<ost::DualRTPUDPIPv4Channel,ost::DualRTPUDPIPv4Channel,ost::AVPQueue>
-class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public AudioRtpRecordHandler, public ost::TRTPSessionBase<ost::SymmetricRTPChannel, ost::SymmetricRTPChannel, ost::AVPQueue>
+class AudioRtpSession : public ost::TimerPort, public AudioRtpRecordHandler, public ost::SymmetricRTPSession
 {
     public:
         /**
@@ -71,8 +70,10 @@ class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public Aud
 
         virtual void final ();
 
+        void terminateRtpSession();
+
         // Thread associated method
-        virtual void run ();
+        // virtual void run ();
 
         virtual bool onRTPPacketRecv (ost::IncomingRTPPkt&);
 
@@ -102,8 +103,31 @@ class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public Aud
          */
         void updateSessionMedia (AudioCodec *);
 
+        /**
+         * Send encoded data to peer
+         */
+        void sendMicData();
+
     private:
 
+        class AudioRtpThread : public ost::Thread, public ost::TimerPort
+        {
+            public:
+                AudioRtpThread (AudioRtpSession *session);
+                ~AudioRtpThread();
+
+                void stopRtpThread (void) {
+                    running = false;
+                }
+
+                virtual void run();
+
+            private:
+                AudioRtpSession *rtpSession;
+
+                bool running;
+        };
+
         /**
          * Set RTP Sockets send/receive timeouts
          */
@@ -120,11 +144,6 @@ class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public Aud
          */
         void setDestinationIpAddress (void);
 
-        /**
-         * Send encoded data to peer
-         */
-        void sendMicData();
-
         /**
          * Receive data from peer
          */
@@ -137,7 +156,7 @@ class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public Aud
         // optional in ost::thread, then
         // it amounts to the same as doing
         // start() with no semaphore at all.
-        ost::Semaphore * _mainloopSemaphore;
+        ost::Semaphore *_mainloopSemaphore;
 
         // Main destination address for this rtp session.
         // Stored in case or reINVITE, which may require to forget
@@ -181,6 +200,12 @@ class AudioRtpSession : protected ost::Thread, public ost::TimerPort, public Aud
         SIPCall * _ca;
 
         bool _isStarted;
+
+        AudioRtpThread *_rtpThread;
+
+    public:
+
+        friend class AudioRtpThread;
 };
 
 }
