@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
+ *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -50,20 +51,18 @@ namespace sfl
 
 AudioZrtpSession::AudioZrtpSession (ManagerImpl * manager, SIPCall * sipcall, const std::string& zidFilename) :
     // ost::SymmetricZRTPSession (ost::InetHostAddress (sipcall->getLocalIp().c_str()), sipcall->getLocalAudioPort()),
-    AudioRtpRecordHandler (manager, sipcall),
+    AudioRtpRecordHandler (sipcall),
     ost::TRTPSessionBase<ost::SymmetricRTPChannel, ost::SymmetricRTPChannel, ost::ZrtpQueue> (ost::InetHostAddress (sipcall->getLocalIp().c_str()),
             sipcall->getLocalAudioPort(),
             0,
             ost::MembershipBookkeeping::defaultMembersHashSize,
             ost::defaultApplication())
     , _zidFilename (zidFilename)
-    , _time (new ost::Time())
     , _mainloopSemaphore (0)
     , _manager (manager)
     , _timestamp (0)
     , _timestampIncrement (0)
     , _timestampCount (0)
-    , _countNotificationTime (0)
     , _ca (sipcall)
 {
     _debug ("AudioZrtpSession initialized");
@@ -89,12 +88,13 @@ AudioZrtpSession::~AudioZrtpSession()
         throw;
     }
 
-    _manager->getAudioDriver()->getMainBuffer()->unBindAll (_ca->getCallId());
+    Manager::instance().getMainBuffer()->unBindAll (_ca->getCallId());
+}
 
-    if (_time)
-        delete _time;
 
-    _time = NULL;
+void AudioZrtpSession::final()
+{
+    delete this;
 }
 
 
@@ -177,19 +177,49 @@ void AudioZrtpSession::setSessionMedia (AudioCodec* audioCodec)
     _debug ("AudioZrtpSession: RTP timestamp increment: %d", _timestampIncrement);
 
     // Even if specified as a 16 kHz codec, G722 requires rtp sending rate to be 8 kHz
-    if (payloadType == g722PayloadType) {
-        _debug ("AudioZrtpSession: Setting G722 payload format");
-        setPayloadFormat (ost::DynamicPayloadFormat ( (ost::PayloadType) payloadType, g722RtpClockRate));
-    } else if (dynamic) {
-        _debug ("AudioZrtpSession: Setting dynamic payload format");
+    if (dynamic) {
+        _debug ("AudioRtpSession: Setting dynamic payload format");
         setPayloadFormat (ost::DynamicPayloadFormat ( (ost::PayloadType) payloadType, smplRate));
-    } else if (dynamic && payloadType != g722PayloadType) {
-        _debug ("AudioZrtpSession: Setting static payload format");
+    } else {
+        _debug ("AudioRtpSession: Setting static payload format");
         setPayloadFormat (ost::StaticPayloadFormat ( (ost::StaticPayloadType) payloadType));
     }
 
 }
 
+void AudioZrtpSession::updateSessionMedia (AudioCodec *audioCodec)
+{
+    _debug ("AudioRtpSession: Update session media");
+
+    //
+    updateRtpMedia (audioCodec);
+
+    int payloadType = getCodecPayloadType();
+    int frameSize = getCodecFrameSize();
+    int smplRate = getCodecSampleRate();
+    int dynamic = getHasDynamicPayload();
+
+    // G722 requires timetamp to be incremented at 8khz
+    if (payloadType == g722PayloadType)
+        _timestampIncrement = g722RtpTimeincrement;
+    else
+        _timestampIncrement = frameSize;
+
+    _debug ("AudioRptSession: Codec payload: %d", payloadType);
+    _debug ("AudioRtpSession: Codec sampling rate: %d", smplRate);
+    _debug ("AudioRtpSession: Codec frame size: %d", frameSize);
+    _debug ("AudioRtpSession: RTP timestamp increment: %d", _timestampIncrement);
+
+    // Even if specified as a 16 kHz codec, G722 requires rtp sending rate to be 8 kHz
+    if (dynamic) {
+        _debug ("AudioRtpSession: Setting dynamic payload format");
+        setPayloadFormat (ost::DynamicPayloadFormat ( (ost::PayloadType) payloadType, smplRate));
+    } else {
+        _debug ("AudioRtpSession: Setting static payload format");
+        setPayloadFormat (ost::StaticPayloadFormat ( (ost::StaticPayloadType) payloadType));
+    }
+}
+
 void AudioZrtpSession::setDestinationIpAddress (void)
 {
     _info ("AudioZrtpSession: Setting IP address for the RTP session");
@@ -235,6 +265,7 @@ void AudioZrtpSession::updateDestinationIpAddress (void)
     setDestinationIpAddress();
 }
 
+
 void AudioZrtpSession::sendDtmfEvent (sfl::DtmfEvent *dtmf)
 {
     _debug ("AudioZrtpSession: Send Dtmf %d", getEventQueueSize());
@@ -251,7 +282,8 @@ void AudioZrtpSession::sendDtmfEvent (sfl::DtmfEvent *dtmf)
     if (dtmf->newevent)
         setMark (true);
 
-    putData (_timestamp, (const unsigned char*) (& (dtmf->payload)), sizeof (ost::RTPPacket::RFC2833Payload));
+    // putData (_timestamp, (const unsigned char*) (& (dtmf->payload)), sizeof (ost::RTPPacket::RFC2833Payload));
+    sendImmediate (_timestamp, (const unsigned char*) (& (dtmf->payload)), sizeof (ost::RTPPacket::RFC2833Payload));
 
     // This is no more a new event
     if (dtmf->newevent) {
@@ -293,17 +325,12 @@ void AudioZrtpSession::sendMicData()
     if (!compSize)
         return;
 
-    // Reset timestamp to make sure the timing information are up to date
-    if (_timestampCount > RTP_TIMESTAMP_RESET_FREQ) {
-        _timestamp = getCurrentTimestamp();
-        _timestampCount = 0;
-    }
-
     // Increment timestamp for outgoing packet
     _timestamp += _timestampIncrement;
 
     // putData put the data on RTP queue, sendImmediate bypass this queue
     putData (_timestamp, getMicDataEncoded(), compSize);
+    sendImmediate (_timestamp, getMicDataEncoded(), compSize);
 }
 
 
@@ -334,60 +361,35 @@ void AudioZrtpSession::receiveSpeakerData ()
     delete adu;
 }
 
-void AudioZrtpSession::notifyIncomingCall()
-{
-    // Notify (with a beep) an incoming call when there is already a call
-    if (Manager::instance().incomingCallWaiting() > 0) {
-        _countNotificationTime += _time->getSecond();
-        int countTimeModulo = _countNotificationTime % 5000;
-
-        if ( (countTimeModulo - _countNotificationTime) < 0) {
-            Manager::instance().notificationIncomingCall();
-        }
-
-        _countNotificationTime = countTimeModulo;
-    }
-}
-
 int AudioZrtpSession::startRtpThread (AudioCodec* audiocodec)
 {
+    if (_isStarted)
+        return 0;
+
     _debug ("AudioZrtpSession: Starting main thread");
+    _isStarted = true;
     setSessionTimeouts();
     setSessionMedia (audiocodec);
     initBuffers();
     initNoiseSuppress();
     enableStack();
-
     int ret = start (_mainloopSemaphore);
-
     return ret;
 }
 
+void AudioZrtpSession::stopRtpThread ()
+{
+    _debug ("AudioZrtpSession: Stoping main thread");
+
+    disableStack();
+}
+
 void AudioZrtpSession::run ()
 {
 
-    // Timestamp must be initialized randomly
-    _timestamp = getCurrentTimestamp();
-
-    /*
-    int threadSleep = 0;
-
-    if (getCodecSampleRate() != 0) {
-        threadSleep = (getCodecFrameSize() * 1000) / getCodecSampleRate();
-    } else {
-    	// TODO should not be dependent of audio layer frame size
-        threadSleep = getAudioLayerFrameSize();
-    }
-
-    TimerPort::setTimer (threadSleep);
-    */
-
     // Set recording sampling rate
     _ca->setRecordingSmplRate (getCodecSampleRate());
 
-    // Start audio stream (if not started) AND flush all buffers (main and urgent)
-    _manager->getAudioDriver()->startStream();
-
     _debug ("AudioZrtpSession: Entering mainloop for call %s",_ca->getCallId().c_str());
 
     uint32 timeout = 0;
@@ -398,8 +400,6 @@ void AudioZrtpSession::run ()
             timeout = getSchedulingTimeout();
         }
 
-        _manager->getAudioLayerMutex()->enter();
-
         // Send session
         if (getEventQueueSize() > 0) {
             sendDtmfEvent (getEventQueue()->front());
@@ -407,11 +407,6 @@ void AudioZrtpSession::run ()
             sendMicData ();
         }
 
-        // This also should be moved
-        notifyIncomingCall();
-
-        _manager->getAudioLayerMutex()->leave();
-
         setCancel (cancelDeferred);
         controlReceptionService();
         controlTransmissionService();
@@ -424,7 +419,7 @@ void AudioZrtpSession::run ()
 
         if (timeout < 1000) {   // !(timeout/1000)
             setCancel (cancelDeferred);
-            dispatchDataPacket();
+            // dispatchDataPacket();
             setCancel (cancelImmediate);
             timerTick();
         } else {
