@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010 Savoir-Faire Linux Inc.
+ *  Copyright (C) 2004, 2005, 2006, 2009, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
 
 #include "echocancel.h"
 
-// #include <fstream>
+#include <cmath>
 
 EchoCancel::EchoCancel (int smplRate, int frameLength) : _samplingRate (smplRate),
     _frameLength (frameLength),
