@@ -45,7 +45,7 @@ YamlEmitter::~YamlEmitter()
     close();
 }
 
-void YamlEmitter::open()
+void YamlEmitter::open() throw(YamlEmitterException)
 {
 
     _debug ("YamlEmiter: Open");
@@ -63,15 +63,17 @@ void YamlEmitter::open()
 
     yaml_emitter_set_output_file (&emitter, fd);
 
-    if (!yaml_document_initialize (&document, NULL, NULL, NULL, 0, 0))
+    if (yaml_document_initialize (&document, NULL, NULL, NULL, 0, 0) == 0) {
         throw YamlEmitterException ("Could not initialize yaml document while saving configuration");
+    }
 
     // Init the main configuration mapping
-    if ( (topLevelMapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
+    if ( (topLevelMapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0) {
         throw YamlEmitterException ("Could not create top level mapping");
+    }
 }
 
-void YamlEmitter::close()
+void YamlEmitter::close() throw(YamlEmitterException)
 {
     _debug ("YamlEmitter: Close");
 
@@ -85,75 +87,77 @@ void YamlEmitter::close()
         throw YamlEmitterException ("Error closing file descriptor");
 
 
-    _debug ("Config: Configuration file closed successfully");
+    _debug ("YamlEmitter: Configuration file closed successfully");
 
 }
 
-void YamlEmitter::read() {}
-
-void YamlEmitter::write()
-{
-
-}
-
-void YamlEmitter::serializeData()
+void YamlEmitter::serializeData() throw(YamlEmitterException)
 {
     // Document object is destroyed once its content is emitted
-    if (!yaml_emitter_dump (&emitter, &document))
+    if (yaml_emitter_dump (&emitter, &document) == 0) {
         throw YamlEmitterException ("Error while emitting configuration yaml document");
+    }
 }
 
-
-void YamlEmitter::serializeAccount (MappingNode *map)
+void YamlEmitter::serializeAccount (MappingNode *map) throw(YamlEmitterException)
 {
 
     std::string accountstr ("accounts");
 
     int accountid, accountmapping;
 
-    _debug ("YamlEmitter: Serialize account");
-
-    if (map->getType() != MAPPING)
+    if (map->getType() != MAPPING) {
         throw YamlEmitterException ("Node type is not a mapping while writing account");
+    }
 
     if (isFirstAccount) {
+    	_debug("YamlEmitter: Create account sequence");
+
         // accountSequence need to be static outside this scope since reused each time an account is written
-        if ( (accountid = yaml_document_add_scalar (&document, NULL, (yaml_char_t *) accountstr.c_str(), -1, YAML_PLAIN_SCALAR_STYLE)) == 0)
+        if ( (accountid = yaml_document_add_scalar (&document, NULL, (yaml_char_t *) accountstr.c_str(), -1, YAML_PLAIN_SCALAR_STYLE)) == 0) {
             throw YamlEmitterException ("Could not add preference scalar to document");
+        }
 
-        if ( (accountSequence = yaml_document_add_sequence (&document, NULL, YAML_BLOCK_SEQUENCE_STYLE)) == 0)
+        if ( (accountSequence = yaml_document_add_sequence (&document, NULL, YAML_BLOCK_SEQUENCE_STYLE)) == 0) {
             throw YamlEmitterException ("Could not add sequence to document");
+        }
 
-        if (!yaml_document_append_mapping_pair (&document, topLevelMapping, accountid, accountSequence))
+        if (yaml_document_append_mapping_pair (&document, topLevelMapping, accountid, accountSequence) == 0) {
             throw YamlEmitterException ("Could not add mapping pair to top level mapping");
+        }
 
         isFirstAccount = false;
     }
 
-    if ( (accountmapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
+    if ( (accountmapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0) {
         throw YamlEmitterException ("Could not add account mapping to document");
+    }
 
-    if (!yaml_document_append_sequence_item (&document, accountSequence, accountmapping))
+    if (yaml_document_append_sequence_item (&document, accountSequence, accountmapping) == 0) {
         throw YamlEmitterException ("Could not append account mapping to sequence");
+    }
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (accountmapping, iter->first, iter->second);
-        iter++;
+    try {
+    	while (iter != internalmap->end()) {
+    		addMappingItem (accountmapping, iter->first, iter->second);
+    		iter++;
+    	}
+    }
+    catch(YamlEmitterException &e) {
+    	_error("YamlEmitterException: %s", e.what());
+    	throw;
     }
-
 }
 
-void YamlEmitter::serializePreference (MappingNode *map)
+void YamlEmitter::serializePreference (MappingNode *map) throw(YamlEmitterException)
 {
     std::string preferencestr ("preferences");
 
     int preferenceid, preferencemapping;
 
-    _debug ("YamlEmitter: Serialize preference");
-
     if (map->getType() != MAPPING)
         throw YamlEmitterException ("Node type is not a mapping while writing preferences");
 
@@ -163,27 +167,30 @@ void YamlEmitter::serializePreference (MappingNode *map)
     if ( (preferencemapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
         throw YamlEmitterException ("Could not add mapping to document");
 
-    if (!yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping))
+    if (yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping) == 0)
         throw YamlEmitterException ("Could not add mapping pair to top leve mapping");
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (preferencemapping, iter->first, iter->second);
-        iter++;
+    try {
+    	while (iter != internalmap->end()) {
+    		addMappingItem (preferencemapping, iter->first, iter->second);
+    		iter++;
+    	}
+    }
+    catch(YamlEmitterException &e) {
+    	throw;
     }
 
 }
 
-void YamlEmitter::serializeVoipPreference (MappingNode *map)
+void YamlEmitter::serializeVoipPreference (MappingNode *map) throw(YamlEmitterException)
 {
     std::string preferencestr ("voipPreferences");
 
     int preferenceid, preferencemapping;
 
-    _debug ("YamlEmitter: Serialize voip preference");
-
     if (map->getType() != MAPPING)
         throw YamlEmitterException ("Node type is not a mapping while writing preferences");
 
@@ -193,27 +200,30 @@ void YamlEmitter::serializeVoipPreference (MappingNode *map)
     if ( (preferencemapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
         throw YamlEmitterException ("Could not add mapping to document");
 
-    if (!yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping))
+    if (yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping) == 0)
         throw YamlEmitterException ("Could not add mapping pair to top leve mapping");
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (preferencemapping, iter->first, iter->second);
-        iter++;
+    try {
+    	while (iter != internalmap->end()) {
+    		addMappingItem (preferencemapping, iter->first, iter->second);
+    		iter++;
+    	}
+    }
+    catch (YamlEmitterException &e) {
+    	throw;
     }
 
 }
 
-void YamlEmitter::serializeAddressbookPreference (MappingNode *map)
+void YamlEmitter::serializeAddressbookPreference (MappingNode *map) throw(YamlEmitterException)
 {
     std::string preferencestr ("addressbook");
 
     int preferenceid, preferencemapping;
 
-    _debug ("YamlEmitter: Serialize addressbook preferences");
-
     if (map->getType() != MAPPING)
         throw YamlEmitterException ("Node type is not a mapping while writing preferences");
 
@@ -223,27 +233,29 @@ void YamlEmitter::serializeAddressbookPreference (MappingNode *map)
     if ( (preferencemapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
         throw YamlEmitterException ("Could not add mapping to document");
 
-    if (!yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping))
+    if (yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping) == 0)
         throw YamlEmitterException ("Could not add mapping pair to top leve mapping");
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (preferencemapping, iter->first, iter->second);
-        iter++;
-    }
-
+	try {
+		while (iter != internalmap->end()) {
+			addMappingItem (preferencemapping, iter->first, iter->second);
+			iter++;
+		}
+	}
+	catch(YamlEmitterException &e) {
+		throw;
+	}
 }
 
-void YamlEmitter::serializeHooksPreference (MappingNode *map)
+void YamlEmitter::serializeHooksPreference (MappingNode *map) throw(YamlEmitterException)
 {
     std::string preferencestr ("hooks");
 
     int preferenceid, preferencemapping;
 
-    _debug ("YamlEmitter: Serialize hooks preferences");
-
     if (map->getType() != MAPPING)
         throw YamlEmitterException ("Node type is not a mapping while writing preferences");
 
@@ -253,28 +265,30 @@ void YamlEmitter::serializeHooksPreference (MappingNode *map)
     if ( (preferencemapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
         throw YamlEmitterException ("Could not add mapping to document");
 
-    if (!yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping))
+    if (yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping) == 0)
         throw YamlEmitterException ("Could not add mapping pair to top leve mapping");
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (preferencemapping, iter->first, iter->second);
-        iter++;
+    try {
+		while (iter != internalmap->end()) {
+			addMappingItem (preferencemapping, iter->first, iter->second);
+			iter++;
+		}
     }
-
+	catch(YamlEmitterException &e) {
+		throw;
+	}
 }
 
 
-void YamlEmitter::serializeAudioPreference (MappingNode *map)
+void YamlEmitter::serializeAudioPreference (MappingNode *map) throw(YamlEmitterException)
 {
     std::string preferencestr ("audio");
 
     int preferenceid, preferencemapping;
 
-    _debug ("YamlEmitter: Serialize hooks preferences");
-
     if (map->getType() != MAPPING)
         throw YamlEmitterException ("Node type is not a mapping while writing preferences");
 
@@ -284,28 +298,31 @@ void YamlEmitter::serializeAudioPreference (MappingNode *map)
     if ( (preferencemapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
         throw YamlEmitterException ("Could not add mapping to document");
 
-    if (!yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping))
+    if (yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping) == 0)
         throw YamlEmitterException ("Could not add mapping pair to top leve mapping");
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (preferencemapping, iter->first, iter->second);
-        iter++;
+    try {
+    	while (iter != internalmap->end()) {
+    		addMappingItem (preferencemapping, iter->first, iter->second);
+    		iter++;
+    	}
+    }
+    catch(YamlEmitterException &e) {
+    	throw;
     }
 
 }
 
 
-void YamlEmitter::serializeShortcutPreference (MappingNode *map)
+void YamlEmitter::serializeShortcutPreference (MappingNode *map) throw(YamlEmitterException)
 {
     std::string preferencestr ("shortcuts");
 
     int preferenceid, preferencemapping;
 
-    _debug ("YamlEmitter: Serialize shortcuts preferences");
-
     if (map->getType() != MAPPING)
         throw YamlEmitterException ("Node type is not a mapping while writing preferences");
 
@@ -315,17 +332,21 @@ void YamlEmitter::serializeShortcutPreference (MappingNode *map)
     if ( (preferencemapping = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
         throw YamlEmitterException ("Could not add mapping to document");
 
-    if (!yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping))
+    if (yaml_document_append_mapping_pair (&document, topLevelMapping, preferenceid, preferencemapping) == 0)
         throw YamlEmitterException ("Could not add mapping pair to top leve mapping");
 
     Mapping *internalmap = map->getMapping();
     Mapping::iterator iter = internalmap->begin();
 
-    while (iter != internalmap->end()) {
-        addMappingItem (preferencemapping, iter->first, iter->second);
-        iter++;
+    try {
+		while (iter != internalmap->end()) {
+			addMappingItem (preferencemapping, iter->first, iter->second);
+			iter++;
+		}
+    }
+    catch(YamlEmitterException &e) {
+    	throw;
     }
-
 }
 
 
@@ -344,7 +365,7 @@ void YamlEmitter::addMappingItem (int mappingid, Key key, YamlNode *node)
         if ( (temp2 = yaml_document_add_scalar (&document, NULL, (yaml_char_t *) sclr->getValue().c_str(), -1, YAML_PLAIN_SCALAR_STYLE)) == 0)
             throw YamlEmitterException ("Could not add scalar to document");
 
-        if (!yaml_document_append_mapping_pair (&document, mappingid, temp1, temp2))
+        if (yaml_document_append_mapping_pair (&document, mappingid, temp1, temp2) == 0)
             throw YamlEmitterException ("Could not append mapping pair to mapping");
 
     } else if (node->getType() == MAPPING) {
@@ -357,20 +378,25 @@ void YamlEmitter::addMappingItem (int mappingid, Key key, YamlNode *node)
         if ( (temp2 = yaml_document_add_mapping (&document, NULL, YAML_BLOCK_MAPPING_STYLE)) == 0)
             throw YamlEmitterException ("Could not add scalar to document");
 
-        if (!yaml_document_append_mapping_pair (&document, mappingid, temp1, temp2))
+        if (yaml_document_append_mapping_pair (&document, mappingid, temp1, temp2) == 0)
             throw YamlEmitterException ("Could not add mapping pair to mapping");
 
         MappingNode *map = (MappingNode *) node;
         Mapping *internalmap = map->getMapping();
         Mapping::iterator iter = internalmap->begin();
 
-        while (iter != internalmap->end()) {
-            addMappingItem (temp2, iter->first, iter->second);
-            iter++;
+        try {
+        	while (iter != internalmap->end()) {
+        		addMappingItem (temp2, iter->first, iter->second);
+        		iter++;
+        	}
         }
-    } else
+        catch(YamlEmitterException) {
+        	throw;
+        }
+    } else {
         throw YamlEmitterException ("Unknown node type while adding mapping node");
+    }
 }
 
-
 }
