@@ -36,12 +36,14 @@
 #include <stdio.h>
 #include <exception>
 #include <string>
+#include <vector>
 
 namespace Conf
 {
 
 #define PARSER_BUFFERSIZE 65536
-#define PARSER_MAXEVENT 1024
+
+typedef std::vector<yaml_event_t> YamlEventVector;
 
 class YamlParserException : public std::exception
 {
@@ -70,15 +72,15 @@ class YamlParser
 
         ~YamlParser();
 
-        void open();
+        void open() throw(YamlParserException);
 
-        void close();
+        void close() throw(YamlParserException);
 
-        void serializeEvents();
+        void serializeEvents() throw(YamlParserException);
 
-        YamlDocument *composeEvents();
+        YamlDocument *composeEvents() throw(YamlParserException);
 
-        void constructNativeData();
+        void constructNativeData() throw(YamlParserException);
 
         SequenceNode *getAccountSequence (void) {
             return accountSequence;
@@ -113,24 +115,28 @@ class YamlParser
         /**
          * Copy yaml parser event in event_to according to their type.
          */
-        int copyEvent (yaml_event_t *event_to, yaml_event_t *event_from);
+        void copyEvent (yaml_event_t *event_to, yaml_event_t *event_from) throw(YamlParserException);
 
-        void processStream (void);
+        void processStream (void) throw(YamlParserException);
 
-        void processDocument (void);
+        void processDocument (void) throw(YamlParserException);
 
-        void processScalar (YamlNode *topNode);
+        void processScalar (YamlNode *topNode) throw(YamlParserException);
 
-        void processSequence (YamlNode *topNode);
+        void processSequence (YamlNode *topNode) throw(YamlParserException);
 
-        void processMapping (YamlNode *topNode);
+        void processMapping (YamlNode *topNode) throw(YamlParserException);
 
-        void mainNativeDataMapping (MappingNode *map);
-
-        //   void buildAccounts(SequenceNode *map);
+        void mainNativeDataMapping (MappingNode *map) throw(YamlParserException);
 
+        /**
+         * Configuration file name
+         */
         std::string filename;
 
+        /**
+         * Configuration file descriptor
+         */
         FILE *fd;
 
         /**
@@ -141,7 +147,7 @@ class YamlParser
         /**
          * The event structure array.
          */
-        yaml_event_t events[PARSER_MAXEVENT];
+        YamlEventVector events;
 
         /**
          *
