@@ -227,12 +227,12 @@ IAXVoIPLink::terminateIAXCall()
     _callMap.clear();
 }
 
-void IAXVoIPLink::terminateOneCall (const CallID& id)
+void IAXVoIPLink::terminateCall (const CallID& id)
 {
     IAXCall* call = getIAXCall (id);
 
     if (call) {
-        _debug ("IAXVoIPLink::terminateOneCall()::the call is deleted, should close recording file ");
+        _debug ("IAXVoIPLink: Terminate call");
         delete call;
         call = 0;
     }
@@ -415,25 +415,23 @@ IAXVoIPLink::getIAXCall (const CallID& id)
 }
 
 
-int
-IAXVoIPLink::sendRegister (AccountID id UNUSED)
+void
+IAXVoIPLink::sendRegister (AccountID id UNUSED) throw(VoipLinkException)
 {
-    IAXAccount *account;
-    bool result;
-
     _debug ("IAX: Sending registration");
 
-    result = false;
-    account = dynamic_cast<IAXAccount *> (getAccountPtr());
+    IAXAccount *account = dynamic_cast<IAXAccount *> (getAccountPtr());
+
+    if (!account) {
+    	throw VoipLinkException("Account is NULL in send register");
+    }
 
     if (account->getHostname().empty()) {
-        _error ("IAX: Error: Account hostname is empty");
-        return false;
+    	throw VoipLinkException("Account hostname is empty");
     }
 
     if (account->getUsername().empty()) {
-        _error ("IAX: Error: Account username is empty");
-        return false;
+    	throw VoipLinkException("Account username is empty");
     }
 
     // lock
@@ -455,26 +453,24 @@ IAXVoIPLink::sendRegister (AccountID id UNUSED)
         // set the time-out to 15 seconds, after that, resend a registration request.
         // until we unregister.
         _nextRefreshStamp = time (NULL) + 10;
-        result = true;
 
         account->setRegistrationState (Trying);
     }
 
     // unlock
     _mutexIAX.leaveMutex();
-
-    return result;
 }
 
-int
-IAXVoIPLink::sendUnregister (AccountID id UNUSED)
+void
+IAXVoIPLink::sendUnregister (AccountID id UNUSED) throw(VoipLinkException)
 {
-    IAXAccount *account;
+    _debug ("IAXVoipLink: Send unregister");
 
-    account = dynamic_cast<IAXAccount*> (getAccountPtr());
+    IAXAccount *account = dynamic_cast<IAXAccount*> (getAccountPtr());
 
-    if (!account)
-        return 1;
+    if (!account) {
+        throw VoipLinkException("Account is NULL in send unregister");
+    }
 
     _mutexIAX.enterMutex();
 
@@ -489,14 +485,11 @@ IAXVoIPLink::sendUnregister (AccountID id UNUSED)
 
     _nextRefreshStamp = 0;
 
-    _debug ("IAX2 send unregister");
     account->setRegistrationState (Unregistered);
-
-    return SUCCESS;
 }
 
 Call*
-IAXVoIPLink::newOutgoingCall (const CallID& id, const std::string& toUrl)
+IAXVoIPLink::newOutgoingCall (const CallID& id, const std::string& toUrl) throw(VoipLinkException)
 {
     IAXCall* call = new IAXCall (id, Call::Outgoing);
     call->setCodecMap (Manager::instance().getCodecDescriptorMap());
@@ -563,8 +556,6 @@ IAXVoIPLink::hangup (const CallID& id)
         // audiolayer->stopStream();
     }
 
-    terminateOneCall (id);
-
     removeCall (id);
     return true;
 }
@@ -590,8 +581,6 @@ IAXVoIPLink::peerHungup (const CallID& id)
         // audiolayer->stopStream();
     }
 
-    terminateOneCall (id);
-
     removeCall (id);
     return true;
 }
@@ -655,6 +644,13 @@ IAXVoIPLink::transfer (const CallID& id, const std::string& to)
     // removeCall(id);
 }
 
+bool
+IAXVoIPLink::attendedTransfer(const CallID& transferID, const CallID& targetID)
+{
+	// TODO implement attended transfer for IAX
+	return false;
+}
+
 bool
 IAXVoIPLink::refuse (const CallID& id)
 {
@@ -667,8 +663,6 @@ IAXVoIPLink::refuse (const CallID& id)
     iax_reject (call->getSession(), (char*) reason.c_str());
     _mutexIAX.leaveMutex();
 
-
-    // terminateOneCall(id);
     removeCall (id);
 
     return true;
@@ -812,7 +806,6 @@ IAXVoIPLink::iaxHandleCallEvent (iax_event* event, IAXCall* call)
                _mutexIAX.leaveMutex();
                call->setSession(NULL);
                audiolayer->stopStream();
-               terminateOneCall(id);
              */
             removeCall (id);
             break;
@@ -829,7 +822,6 @@ IAXVoIPLink::iaxHandleCallEvent (iax_event* event, IAXCall* call)
 
             call->setState (Call::Error);
             Manager::instance().callFailure (id);
-            // terminateOneCall(id);
             removeCall (id);
             break;
 
@@ -884,7 +876,6 @@ IAXVoIPLink::iaxHandleCallEvent (iax_event* event, IAXCall* call)
             call->setConnectionState (Call::Connected);
             call->setState (Call::Busy);
             Manager::instance().callBusy (id);
-            // terminateOneCall(id);
             removeCall (id);
             break;
 
