@@ -252,6 +252,13 @@ class ManagerImpl
          */
         bool transferCall (const CallID& id, const std::string& to);
 
+        /**
+         * Attended transfer
+         * @param The call id to be transfered
+         * @param The target
+         */
+        bool attendedTransfer(const CallID& transferID, const CallID& targetID);
+
         /**
          * Notify the client the transfer is successful
          */
@@ -851,7 +858,11 @@ class ManagerImpl
 
         void switchAudioManager (void);
 
-        void audioSamplingRateChanged (void);
+        /**
+         * Set the internal audio sampling rate change. Should close the audio layer and
+         * reopen stream at different rate,
+         */
+        void audioSamplingRateChanged (int);
 
         /**
          * Get the desktop mail notification level
@@ -859,13 +870,6 @@ class ManagerImpl
          */
         int32_t getMailNotify (void);
 
-        /**
-         * Retrieve the formatted list of codecs payload in the user config file and
-         * load in the active list of codecs
-         * @return std::vector<std::string>	  The vector containing the active codecs
-         */
-        std::vector<std::string> retrieveActiveCodecs (void);
-
         /**
          * Get the list of the active codecs
          * @return std::vector< ::std::string >  The list of active codecs
@@ -1250,7 +1254,7 @@ class ManagerImpl
          * Path of the ConfigFile
          */
         std::string 	_path;
-        int _exist;
+
         int _setupLoaded;
 
 #ifdef USE_ZEROCONF
