@@ -81,6 +81,7 @@ void Credentials::unserialize (Conf::MappingNode *map)
 SIPAccount::SIPAccount (const AccountID& accountID)
     : Account (accountID, "SIP")
     , _routeSet ("")
+    , _pool (NULL)
     , _regc (NULL)
     , _bRegister (false)
     , _registrationExpire ("")
@@ -98,7 +99,7 @@ SIPAccount::SIPAccount (const AccountID& accountID)
     , _realm (DEFAULT_REALM)
     , _authenticationUsername ("")
     , _tlsSetting (NULL)
-    , _dtmfType (SIPINFO)
+    , _dtmfType (OVERRTP)
     , _tlsEnable ("false")
     , _tlsPortStr (DEFAULT_SIP_TLS_PORT)
     , _tlsCaListFile ("")
@@ -124,7 +125,7 @@ SIPAccount::SIPAccount (const AccountID& accountID)
     , _zrtpNotSuppWarning (true)
 {
 
-    _debug ("Sip account constructor called");
+    _debug ("Sip account constructor for account %s", accountID.c_str());
 
     _stunServerName.ptr = NULL;
     _stunServerName.slen = 0;
@@ -353,6 +354,9 @@ void SIPAccount::unserialize (Conf::MappingNode *map)
         val = NULL;
     }
 
+    // Update codec list which one is used for SDP offer
+    setActiveCodecs (Manager::instance ().unserialize (_codecStr));
+
     val = (Conf::ScalarNode *) (map->getValue (ringtonePathKey));
 
     if (val) {
@@ -621,8 +625,6 @@ void SIPAccount::unserialize (Conf::MappingNode *map)
         val = NULL;
     }
 
-    Account::loadAudioCodecs();
-
 }
 
 
@@ -1028,10 +1030,7 @@ int SIPAccount::initCredential (void)
 
 int SIPAccount::registerVoIPLink()
 {
-    _debug ("Account: Register account %s", getAccountID().c_str());
-
-    // Init general settings
-    // loadConfig();
+    _debug ("SIPAccount: Register account %s", getAccountID().c_str());
 
     if (_hostname.length() >= PJ_MAX_HOSTNAME) {
         return !SUCCESS;
@@ -1042,13 +1041,12 @@ int SIPAccount::registerVoIPLink()
 
     // Init TLS settings if the user wants to use TLS
     if (_tlsEnable == "true") {
-        _debug ("Account: TLS is ennabled for accounr %s", getAccountID().c_str());
+        _debug ("SIPAccount: TLS is ennabled for accounr %s", getAccountID().c_str());
         _transportType = PJSIP_TRANSPORT_TLS;
         initTlsConfiguration();
     }
 
     // Init STUN settings for this account if the user selected it
-
     if (_stunEnabled) {
         _transportType = PJSIP_TRANSPORT_START_OTHER;
         initStunConfiguration ();
@@ -1056,12 +1054,16 @@ int SIPAccount::registerVoIPLink()
         _stunServerName = pj_str ( (char*) _stunServer.data());
     }
 
-    // In our definition of the
-    // ip2ip profile (aka Direct IP Calls),
-    // no registration should be performed
-    if (_accountID != IP2IP_PROFILE) {
-        int status = _link->sendRegister (_accountID);
-        ASSERT (status , SUCCESS);
+    try {
+        // In our definition of the
+    	// ip2ip profile (aka Direct IP Calls),
+    	// no registration should be performed
+    	if (_accountID != IP2IP_PROFILE) {
+    		_link->sendRegister (_accountID);
+    	}
+    }
+    catch(VoipLinkException &e) {
+    	_error("SIPAccount: %s", e.what());
     }
 
     return SUCCESS;
@@ -1069,17 +1071,22 @@ int SIPAccount::registerVoIPLink()
 
 int SIPAccount::unregisterVoIPLink()
 {
-    _debug ("Unregister account %s" , getAccountID().c_str());
+    _debug ("SIPAccount: Unregister account %s" , getAccountID().c_str());
 
     if (_accountID == IP2IP_PROFILE) {
         return true;
     }
 
-    if (_link->sendUnregister (_accountID)) {
+    try {
+    	_link->sendUnregister (_accountID);
         setRegistrationInfo (NULL);
-        return true;
-    } else
-        return false;
+    }
+    catch(VoipLinkException &e) {
+    	_error("SIPAccount: %s", e.what());
+    	return false;
+    }
+
+    return true;
 
 }
 
