@@ -50,6 +50,7 @@
 
 #include <map>
 #include <sstream>
+#include <exception>
 
 class EventThread;
 class SIPCall;
@@ -58,9 +59,23 @@ class SIPCall;
 #define RANDOM_SIP_PORT   rand() % 64000 + 1024
 
 // To set the verbosity. From 0 (min) to 6 (max)
-#define PJ_LOG_LEVEL 0
+#define PJ_LOG_LEVEL 6
 
-#define SipTransportMap std::map<std::string, pjsip_transport*>
+class SIPVoipLinkException : public std::exception
+{
+    public:
+        SIPVoipLinkException (const std::string& str="") throw() : errstr (str) {}
+
+        virtual ~SIPVoipLinkException() throw() {}
+
+        virtual const char *what() const throw() {
+            std::string expt ("UserAgent: SIPVoipLinkException occured: ");
+            expt.append (errstr);
+            return expt.c_str();
+        }
+    private:
+        std::string errstr;
+};
 
 /**
  * @file sipvoiplink.h
@@ -71,7 +86,20 @@ class SIPCall;
 
 class SIPVoIPLink : public VoIPLink
 {
-    public:
+	typedef std::map<std::string, pjsip_transport*>  SipTransportMap;
+
+	public:
+
+	    /* Copy Constructor */
+        SIPVoIPLink (const SIPVoIPLink& rh);
+
+        /**
+         * Destructor
+         */
+        ~SIPVoIPLink();
+
+        /* Assignment Operator */
+        SIPVoIPLink& operator= (const SIPVoIPLink& rh);
 
         /**
          * Singleton method. Enable to retrieve the unique static instance
@@ -80,45 +108,46 @@ class SIPVoIPLink : public VoIPLink
         static SIPVoIPLink* instance (const AccountID& id);
 
         /**
-         * Destructor
+         * Increment the number of SIP account connected to this link
          */
-        ~SIPVoIPLink();
+        void incrementClients (void) {
+            _clients++;
+        }
 
-        /* Copy Constructor */
-        SIPVoIPLink (const SIPVoIPLink& rh);
-
-        /* Assignment Operator */
-        SIPVoIPLink& operator= (const SIPVoIPLink& rh);
+        /**
+         * Decrement the number of SIP account connected to this link
+         */
+        void decrementClients (void);
 
         /**
          * Try to initiate the pjsip engine/thread and set config
          * @return bool True if OK
          */
-        bool init (void);
+        virtual bool init (void);
 
         /**
          * Shut the library and clean up
          */
-        void terminate (void);
+        virtual void terminate (void);
 
         /**
          * Event listener. Each event send by the call manager is received and handled from here
          */
-        void getEvent (void);
+        virtual void getEvent (void);
 
         /**
          * Build and send SIP registration request
          * @return bool True on success
          *		  false otherwise
          */
-        int sendRegister (AccountID id);
+        virtual void sendRegister (AccountID id) throw(VoipLinkException);
 
         /**
          * Build and send SIP unregistration request
          * @return bool True on success
          *		  false otherwise
          */
-        int sendUnregister (AccountID id);
+        virtual void sendUnregister (AccountID id) throw(VoipLinkException);
 
         /**
          * Place a new call
@@ -126,49 +155,49 @@ class SIPVoIPLink : public VoIPLink
          * @param toUrl  The Sip address of the recipient of the call
          * @return Call* The current call
          */
-        Call* newOutgoingCall (const CallID& id, const std::string& toUrl);
+        virtual Call* newOutgoingCall (const CallID& id, const std::string& toUrl) throw (VoipLinkException);
 
         /**
          * Answer the call
          * @param id The call identifier
          * @return int True on success
          */
-        bool answer (const CallID& id);
+        virtual bool answer (const CallID& id);
 
         /**
          * Hang up the call
          * @param id The call identifier
          * @return bool True on success
          */
-        bool hangup (const CallID& id);
+        virtual bool hangup (const CallID& id);
 
         /**
          * Hang up the call
          * @param id The call identifier
          * @return bool True on success
          */
-        bool peerHungup (const CallID& id);
+        virtual bool peerHungup (const CallID& id);
 
         /**
          * Cancel the call
          * @param id The call identifier
          * @return bool True on success
          */
-        bool cancel (const CallID& id);
+        virtual bool cancel (const CallID& id);
 
         /**
          * Put the call on hold
          * @param id The call identifier
          * @return bool True on success
          */
-        bool onhold (const CallID& id);
+        virtual bool onhold (const CallID& id);
 
         /**
          * Put the call off hold
          * @param id The call identifier
          * @return bool True on success
          */
-        bool offhold (const CallID& id);
+        virtual bool offhold (const CallID& id);
 
         /**
          * Transfer the call
@@ -176,9 +205,19 @@ class SIPVoIPLink : public VoIPLink
          * @param to The recipient of the transfer
          * @return bool True on success
          */
-        bool transfer (const CallID& id, const std::string& to);
+        virtual bool transfer (const CallID& id, const std::string& to);
 
-        /** Handle the incoming refer msg, not finished yet */
+        /**
+         * Attended transfer
+         * @param The transfered call id
+         * @param The target call id
+         * @return True on success
+         */
+        virtual bool attendedTransfer(const CallID&, const CallID&);
+
+        /**
+         * Handle the incoming refer msg, not finished yet
+         */
         bool transferStep2 (SIPCall* call);
 
         /**
@@ -186,7 +225,12 @@ class SIPVoIPLink : public VoIPLink
          * @param id The call identifier
          * @return bool True on success
          */
-        bool refuse (const CallID& id);
+        virtual bool refuse (const CallID& id);
+
+        /**
+         * Terminate only one call
+         */
+        virtual void terminateCall (const CallID& id);
 
         /**
          * Send DTMF refering to account configuration
@@ -194,7 +238,7 @@ class SIPVoIPLink : public VoIPLink
          * @param code  The char code
          * @return bool True on success
          */
-        bool carryingDTMFdigits (const CallID& id, char code);
+        virtual bool carryingDTMFdigits (const CallID& id, char code);
 
         /**
          * Send Dtmf using SIP INFO message
@@ -206,16 +250,6 @@ class SIPVoIPLink : public VoIPLink
          */
         bool dtmfOverRtp (SIPCall* call, char code);
 
-        /**
-         * Terminate every call not hangup | brutal | Protected by mutex
-         */
-        void terminateSIPCall();
-
-        /**
-         * Terminate only one call
-         */
-        void terminateOneCall (const CallID& id);
-
         /**
          * Send an outgoing call invite
          * @param call  The current call
@@ -231,6 +265,13 @@ class SIPVoIPLink : public VoIPLink
          */
         bool SIPStartCall (SIPCall* call, const std::string& subject);
 
+        /**
+         * Start a new SIP call using the IP2IP profile
+         * @param The call id
+         * @param The target sip uri
+         */
+        bool SIPNewIpToIpCall (const CallID& id, const std::string& to);
+
         /**
          * Tell the user that the call was answered
          * @param
@@ -252,16 +293,27 @@ class SIPVoIPLink : public VoIPLink
         /**
          * The call pointer was released
          * If the call was not cleared before, report an error
-         * @param
+         * @param sip call
          */
         void SIPCallReleased (SIPCall *call);
 
         /**
          * Handle a re-invite request by the remote peer.
          * A re-invite is an invite request inside a dialog.
-         * When receiving a re-invite, we close the current rtp session and create a new one with the updated information
+         * When receiving a re-invite, we close the current rtp session and create
+         * a new one with the updated information
+         * @param sip call
          */
-        void handle_reinvite (SIPCall *call);
+        void SIPHandleReinvite (SIPCall *call);
+
+        /**
+         * Send a reINVITE inside an active dialog to modify its state
+         * @param sip call
+         * @param the direction, "sendrecv" or "sendonly"
+         */
+        int SIPInvSessionReinvite (SIPCall *call, std::string direction="");
+
+        pj_caching_pool *getMemoryPoolFactory();
 
         /**
          * SIPCall accessor
@@ -270,40 +322,16 @@ class SIPVoIPLink : public VoIPLink
          */
         SIPCall* getSIPCall (const CallID& id);
 
-        /** when we init the listener, how many times we try to bind a port? */
-        int _nbTryListenAddr;
-
-        /** Increment the number of SIP account connected to this link */
-        void incrementClients (void) {
-            _clients++;
-        }
-
-        /** Decrement the number of SIP account connected to this link */
-        void decrementClients (void);
-
-        /**
-        	* Set Recording
-        	* @param id The call identifier
-        	*/
-        void setRecording (const CallID& id);
-
-        /**
-         * Returning state (true recording)
-         * @param id The call identifier
-         */
-        bool isRecording (const CallID& id);
-
         /**
          * Return the codec protocol used for this call
          * @param id The call identifier
          */
         std::string getCurrentCodecName();
 
-        int inv_session_reinvite (SIPCall *call, std::string direction="");
-
-        bool new_ip_to_ip_call (const CallID& id, const std::string& to);
-
-        std::string get_useragent_name (const AccountID& id);
+        /**
+         * Retrive useragent name from account
+         */
+        std::string getUseragentName (const AccountID& id);
 
         /**
          * List all the interfaces on the system and return
@@ -315,7 +343,6 @@ class SIPVoIPLink : public VoIPLink
          */
         std::vector<std::string> getAllIpInterface (void);
 
-
         /**
         * List all the interfaces on the system and return
         * a vector list containing their name (eth0, eth0:1 ...).
@@ -326,18 +353,16 @@ class SIPVoIPLink : public VoIPLink
         */
         std::vector<std::string> getAllIpInterfaceByName (void);
 
-
         /**
-             * List all the interfaces on the system and return
-             * a vector list containing their name (eth0, eth0:1 ...).
-             * @param void
-             * @return std::vector<std::string> A std::string vector
-             * of interface name available on all of the interfaces on
-             * the system.
-             */
+         * List all the interfaces on the system and return
+         * a vector list containing their name (eth0, eth0:1 ...).
+         * @param void
+         * @return std::vector<std::string> A std::string vector
+         * of interface name available on all of the interfaces on
+         * the system.
+         */
         std::string getInterfaceAddrFromName (std::string ifaceName);
 
-
         /**
          * Initialize the transport selector
          * @param transport		A transport associated with an account
@@ -345,7 +370,7 @@ class SIPVoIPLink : public VoIPLink
          *
          * @return pj_status_t		PJ_SUCCESS if the structure was successfully initialized
          */
-        pj_status_t init_transport_selector (pjsip_transport *transport, pjsip_tpselector **tp_sel);
+        pj_status_t initTransportSelector (pjsip_transport *, pjsip_tpselector **, pj_pool_t *);
 
         /**
          * Requests PJSIP library for local IP address, using pj_gethostbyname()
@@ -355,6 +380,16 @@ class SIPVoIPLink : public VoIPLink
          */
         bool loadSIPLocalIP (std::string *addr);
 
+        /**
+         * Helper function for creating a route set from information
+         * stored in configuration file.
+         */
+        pjsip_route_hdr *createRouteSet(Account *account, pj_pool_t *pool);
+
+        /**
+         * Wrapper around getaddrinfo
+         */
+        bool dnsResolution(pjsip_tx_data *tdata);
 
         /**
          * This function unset the transport for a given account. It tests wether the
@@ -364,11 +399,10 @@ class SIPVoIPLink : public VoIPLink
          */
         void shutdownSipTransport (const AccountID& accountID);
 
-
         /**
          * Send a SIP message to a call identified by its callid
          *
-        * @param The InstantMessaging module which contains formating, parsing and sending method
+         * @param The InstantMessaging module which contains formating, parsing and sending method
          * @param The Id of the call to send the message to
          * @param The actual message to be transmitted
          * @param The sender of this message (could be another participant of a conference)
@@ -377,6 +411,21 @@ class SIPVoIPLink : public VoIPLink
          */
         bool sendTextMessage (sfl::InstantMessaging *module, const std::string& callID, const std::string& message, const std::string& from);
 
+        /**
+         * Retrieve display name from the
+         */
+        static std::string parseDisplayName(char *);
+
+        /**
+         * Remove the "sip:" or "sips:" from input uri
+         */
+        static void stripSipUriPrefix(std::string&);
+
+        /**
+         * when we init the listener, how many times we try to bind a port?
+         */
+        int _nbTryListenAddr;
+
     private:
         /**
          * Constructor
@@ -387,16 +436,7 @@ class SIPVoIPLink : public VoIPLink
         /* The singleton instance */
         static SIPVoIPLink* _instance;
 
-        /**
-         * Enable the SIP SRV resolver
-         * @param endpt     The SIP endpoint
-         * @param p_resv    Pointer to receive The DNS resolver instance
-         *
-         * @return pj_status_t  PJ_SUCCESS on success
-         */
-        pj_status_t enable_dns_srv_resolver (pjsip_endpoint *endpt, pj_dns_resolver ** p_resv);
-
-        void busy_sleep (unsigned msec);
+        void busySleep (unsigned msec);
 
         /**
          * Initialize the PJSIP library
@@ -404,13 +444,16 @@ class SIPVoIPLink : public VoIPLink
          *
          * @return bool True on success
          */
-        bool pjsip_init();
+        bool pjsipInit();
 
         /**
          * Delete link-related stuff like calls
          */
-        bool pjsip_shutdown (void);
+        bool pjsipShutdown (void);
 
+        /**
+         * Resolve public address for this account
+         */
         pj_status_t stunServerResolve (AccountID id);
 
 
@@ -486,32 +529,15 @@ class SIPVoIPLink : public VoIPLink
          */
         pj_status_t createAlternateUdpTransport (AccountID id);
 
-
         /**
-         * UDP Transports are stored in this map in order to retreive them in case
-         * several accounts would share the same port number.
-         */
-        SipTransportMap _transportMap;
-
-        /** For registration use only */
-        int _regPort;
-
-        /** Threading object */
-        EventThread* _evThread;
-        ost::Mutex _mutexSIP;
-
-        /* Number of SIP accounts connected to the link */
-        int _clients;
-
-        /*
          * Get the correct address to use (ie advertised) from
-             * a uri. The corresponding transport that should be used
-             * with that uri will be discovered.
-             *
-             * @param uri The uri from which we want to discover the address to use
-             * @param transport The transport to use to discover the address
-             * @return pj_str_t The extern (public) address
-             */
+         * a uri. The corresponding transport that should be used
+         * with that uri will be discovered.
+         *
+         * @param uri The uri from which we want to discover the address to use
+         * @param transport The transport to use to discover the address
+         * @return pj_str_t The extern (public) address
+         */
         std::string findLocalAddressFromUri (const std::string& uri, pjsip_transport *transport);
 
         /*
@@ -522,6 +548,32 @@ class SIPVoIPLink : public VoIPLink
          */
         int findLocalPortFromUri (const std::string& uri, pjsip_transport *transport);
 
+        /**
+         * UDP Transports are stored in this map in order to retreive them in case
+         * several accounts would share the same port number.
+         */
+        SipTransportMap _transportMap;
+
+        /**
+         * For registration use only
+         */
+        int _regPort;
+
+        /**
+         * Threading object
+         */
+        EventThread* _evThread;
+
+        /**
+         * Global mutex for the sip voiplink
+         */
+        ost::Mutex _mutexSIP;
+
+        /**
+         * Number of SIP accounts connected to the link
+         */
+        int _clients;
+
 
         friend class SIPTest;
 };
