@@ -53,7 +53,7 @@ class SIPTest : public CppUnit::TestCase {
      * Use cppunit library macros to add unit test the factory
      */
     CPPUNIT_TEST_SUITE( SIPTest );
-    CPPUNIT_TEST ( testSimpleOutgoingIpCall );
+    // CPPUNIT_TEST ( testSimpleOutgoingIpCall );
     // CPPUNIT_TEST ( testSimpleIncomingIpCall );
     // CPPUNIT_TEST ( testTwoOutgoingIpCall );
     // CPPUNIT_TEST ( testTwoIncomingIpCall );
